# Copyright NTESS. See COPYRIGHT file for details.
#
# SPDX-License-Identifier: MIT

import random
from itertools import cycle

from .. import version
from ..third_party.color import colorize
from . import logging


def banner(color: bool = True) -> str:
    info = random.choice(banners)
    banner = info["banner"]
    logging.debug(f"banner font: {info['font']}")
    if not color:
        return banner + f"\nversion: {version.version}"
    colors = cycle(["c", "c", "b", "b", "m", "m", "G", "G"])
    lines: list[str] = []
    for line in banner.splitlines():
        if not line.split() and not lines:
            continue
        elif line.split():
            line = colorize("@*%s{%s}" % (next(colors), line))
        lines.append(line)
    banner = "\n".join(lines).rstrip()
    return banner + f"\nversion: {version.version}"


banners: list[dict[str, str]] = [
    {
        "font": "cybermedium",
        "banner": "____ ____ _  _ ____ ____ _   _ \n|    |__| |\\ | |__| |__/  \\_/  \n|___ |  | | \\| |  | |  \\   |   \n                               \n",
    },
    {
        "font": "henry3d",
        "banner": "                                                           \n   ____      ___ _    _ ___      ___ _    _ ___    _    _  \n  F ___J.   F __` L  J '__ J    F __` L  J '__ \", J |  | L \n | |---LJ  | |--| |  | |__| |  | |--| |  | |__|-J | |  | | \n F L___--. F L__J J  F L  J J  F L__J J  F L  `-' F L__J J \nJ\\______/FJ\\____,__LJ__L  J__LJ\\____,__LJ__L      )-____  L\n J______F  J____,__F|__L  J__| J____,__F|__L     J\\______/F\n                                                  J______F \n",
    },
    {
        "font": "twisted",
        "banner": "  _____     _____      __   __      _____      __ __      __  __   \n /\\ __/\\   /\\___/\\    /_/\\ /\\_\\    /\\___/\\    /_/\\__/\\  /\\  /\\  /\\ \n ) )__\\/  / / _ \\ \\   ) ) \\ ( (   / / _ \\ \\   ) ) ) ) ) \\ \\ \\/ / / \n/ / /     \\ \\(_)/ /  /_/   \\ \\_\\  \\ \\(_)/ /  /_/ /_/_/   \\ \\__/ /  \n\\ \\ \\_    / / _ \\ \\  \\ \\ \\   / /  / / _ \\ \\  \\ \\ \\ \\ \\    \\__/ /   \n ) )__/\\ ( (_( )_) )  )_) \\ (_(  ( (_( )_) )  )_) ) \\ \\   / / /    \n \\/___\\/  \\/_/ \\_\\/   \\_\\/ \\/_/   \\/_/ \\_\\/   \\_\\/ \\_\\/   \\/_/     \n                                                                   \n",
    },
    {
        "font": "chartr",
        "banner": "                         \n                         \n                         \n                         \n #   #  ####  #  ## ## # \n# #  ## #  #  ## #   # # \n#   # # #  # # # #   ##  \n ##  ## # ##  ## #   #   \n                     #   \n                    #    \n",
    },
    {
        "font": "type_set",
        "banner": "   ###      ##     #    #     ##     #####     #   #  \n  #   #    #  #    ##   #    #  #    #    #    #   #  \n #        #    #   # #  #   #    #   #    #    #   #  \n #        ######   #  # #   ######   #####      ###   \n #        #    #   #   ##   #    #   #  #        #    \n  #   #   #    #   #    #   #    #   #   #       #    \n   ###    #    #   #    #   #    #   #    #      #    \n                                                      \n",
    },
    {
        "font": "isometric2",
        "banner": "      ___           ___           ___           ___           ___                 \n     /\\__\\         /\\  \\         /\\  \\         /\\  \\         /\\  \\                \n    /:/  /        /::\\  \\        \\:\\  \\       /::\\  \\       /::\\  \\         ___   \n   /:/  /        /:/\\:\\  \\        \\:\\  \\     /:/\\:\\  \\     /:/\\:\\__\\       /|  |  \n  /:/  /  ___   /:/ /::\\  \\   _____\\:\\  \\   /:/ /::\\  \\   /:/ /:/  /      |:|  |  \n /:/__/  /\\__\\ /:/_/:/\\:\\__\\ /::::::::\\__\\ /:/_/:/\\:\\__\\ /:/_/:/__/___    |:|  |  \n \\:\\  \\ /:/  / \\:\\/:/  \\/__/ \\:\\~~\\~~\\/__/ \\:\\/:/  \\/__/ \\:\\/:::::/  /  __|:|__|  \n  \\:\\  /:/  /   \\::/__/       \\:\\  \\        \\::/__/       \\::/~~/~~~~  /::::\\  \\  \n   \\:\\/:/  /     \\:\\  \\        \\:\\  \\        \\:\\  \\        \\:\\~~\\      ~~~~\\:\\  \\ \n    \\::/  /       \\:\\__\\        \\:\\__\\        \\:\\__\\        \\:\\__\\          \\:\\__\\\n     \\/__/         \\/__/         \\/__/         \\/__/         \\/__/           \\/__/\n",
    },
    {
        "font": "stellar",
        "banner": "                                                    \n                                                    \n   `...   `..    `.. `..     `..    `. `...`..   `..\n `..    `..  `..  `..  `.. `..  `..  `..    `.. `.. \n`..    `..   `..  `..  `..`..   `..  `..      `...  \n `..   `..   `..  `..  `..`..   `..  `..       `..  \n   `...  `.. `...`...  `..  `.. `...`...      `..   \n                                            `..     \n",
    },
    {
        "font": "impossible",
        "banner": "          _               _                   _                   _                   _       _        _   \n        /\\ \\             / /\\                /\\ \\     _          / /\\                /\\ \\    /\\ \\     /\\_\\ \n       /  \\ \\           / /  \\              /  \\ \\   /\\_\\       / /  \\              /  \\ \\   \\ \\ \\   / / / \n      / /\\ \\ \\         / / /\\ \\            / /\\ \\ \\_/ / /      / / /\\ \\            / /\\ \\ \\   \\ \\ \\_/ / /  \n     / / /\\ \\ \\       / / /\\ \\ \\          / / /\\ \\___/ /      / / /\\ \\ \\          / / /\\ \\_\\   \\ \\___/ /   \n    / / /  \\ \\_\\     / / /  \\ \\ \\        / / /  \\/____/      / / /  \\ \\ \\        / / /_/ / /    \\ \\ \\_/    \n   / / /    \\/_/    / / /___/ /\\ \\      / / /    / / /      / / /___/ /\\ \\      / / /__\\/ /      \\ \\ \\     \n  / / /            / / /_____/ /\\ \\    / / /    / / /      / / /_____/ /\\ \\    / / /_____/        \\ \\ \\    \n / / /________    / /_________/\\ \\ \\  / / /    / / /      / /_________/\\ \\ \\  / / /\\ \\ \\           \\ \\ \\   \n/ / /_________\\  / / /_       __\\ \\_\\/ / /    / / /      / / /_       __\\ \\_\\/ / /  \\ \\ \\           \\ \\_\\  \n\\/____________/  \\_\\___\\     /____/_/\\/_/     \\/_/       \\_\\___\\     /____/_/\\/_/    \\_\\/            \\/_/  \n                                                                                                           \n",
    },
    {
        "font": "future_7",
        "banner": "  ####     ###    ##   ##    ###    ######    ##  ##  \n ##  ##   ## ##   ###  ##   ## ##   ##   ##   ##  ##  \n##       ##   ##  #### ##  ##   ##  ##   ##    #  #   \n##       ##   ##  #######  ##   ##  ##  ###    ####   \n##       #######  ## ####  #######  #####       ##    \n ##  ##  ##   ##  ##  ###  ##   ##  ## ###      ##    \n  ####   ##   ##  ##   ##  ##   ##  ##  ###     ##    \n                                                      \n",
    },
    {
        "font": "fairligh",
        "banner": "   ####    #####   ##  ##    #####  ######   ##   ##  \n  ##      ##      ###       ##           ##  ##       \n ##      ##   ##  #### ##  ##   ##  ##   ##  ##   ##  \n ##      #######  #######  #######  ######    ## ##   \n ##      ##   ##  ##  ###  ##   ##  ## ##      ###    \n ##  ##  ##   ##  ##   ##  ##   ##  ##  ##     ###    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##    ###    \n                                                      \n",
    },
    {
        "font": "double",
        "banner": "  ___ ___ __  __ ___ ____ _  _\n //  // \\\\||\\ ||// \\\\|| \\\\\\\\//\n((   ||=||||\\\\||||=||||_// )/ \n \\\\__|| |||| \\|||| |||| \\\\//  \n                              \n",
    },
    {
        "font": "charact3",
        "banner": "                                                      \n  ######   ######   ##  ##   ######   #####   ##   ## \n ###  ##  ###  ##   ### ##  ###  ##   ##  ##   ## ##  \n ##       ##  ##   ######   ##  ##   ##  ###    ###   \n##       #######   ## ###  #######   ######     ##    \n##  ##   ##  ##   ##  ##   ##  ##   ##  ##     ##     \n######   ##  ##   ##  ##   ##  ##   ##   ###   ##     \n                                                      \n",
    },
    {
        "font": "xcour",
        "banner": "                                    \n                                    \n                                    \n                                    \n ##   ##   # ##    ##   # ### ## ## \n#  #    #   #  #     #   #     #  # \n#     ###   #  #   ###   #     #  # \n#  # #  #   #  #  #  #   #     #  # \n ##   ## # ### ##  ## # ####    ##  \n                                #   \n                              ##    \n",
    },
    {
        "font": "4x4_offr",
        "banner": "  ####      ##     ##  ##     ##     #####    ##  ##  \n ##  ##    ####    ### ##    ####    ##  ##   ##  ##  \n ##       ##  ##   ######   ##  ##   ##  ##   ##  ##  \n ##       ######   ######   ######   #####     ####   \n ##       ##  ##   ## ###   ##  ##   ####       ##    \n ##  ##   ##  ##   ##  ##   ##  ##   ## ##      ##    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "usa",
        "banner": "                                                      \n                                                      \n #######  #######  ###  ##  #######  #######  ##   ## \n               ##  #### ##       ##       ##  ##   ## \n ##       #######  ## ####  #######  #######  ####### \n ##       ##   ##  ##  ###  ##   ##  ##  ##        ## \n #######  ##   ##  ##   ##  ##   ##  ##   ##  ####### \n                                                      \n",
    },
    {
        "font": "clr5x6",
        "banner": "                                    \n  ###   ###  # #    ###  # ##  #  # \n #     #  #  ## #  #  #  ##    #  # \n #     # ##  #  #  # ##  #      ### \n  ###   # #  #  #   # #  #        # \n                                ##  \n",
    },
    {
        "font": "larry3d",
        "banner": "                                                       \n                                                       \n  ___      __       ___       __      _ __   __  __    \n /'___\\  /'__`\\   /' _ `\\   /'__`\\   /\\`'__\\/\\ \\/\\ \\   \n/\\ \\__/ /\\ \\L\\.\\_ /\\ \\/\\ \\ /\\ \\L\\.\\_ \\ \\ \\/ \\ \\ \\_\\ \\  \n\\ \\____\\\\ \\__/.\\_\\\\ \\_\\ \\_\\\\ \\__/.\\_\\ \\ \\_\\  \\/`____ \\ \n \\/____/ \\/__/\\/_/ \\/_/\\/_/ \\/__/\\/_/  \\/_/   `/___/> \\\n                                                 /\\___/\n                                                 \\/__/ \n",
    },
    {
        "font": "doom",
        "banner": "                                        \n                                        \n  ___   __ _  _ __    __ _  _ __  _   _ \n / __| / _` || '_ \\  / _` || '__|| | | |\n| (__ | (_| || | | || (_| || |   | |_| |\n \\___| \\__,_||_| |_| \\__,_||_|    \\__, |\n                                   __/ |\n                                  |___/ \n",
    },
    {
        "font": "eca",
        "banner": "                                                      \n  #####     ###    #### ##    ###    ######   ### ### \n ### ###   #####   #### ##   #####   ### ###  ### ### \n ###      ### ###  #######  ### ###  ### ###   #####  \n ###      ### ###  #######  ### ###  ######     ###   \n ### ###  #######  ### ###  #######  ### ###    ###   \n  #####   ### ###  ### ###  ### ###  ### ###    ###   \n                                                      \n",
    },
    {
        "font": "standard",
        "banner": "                                        \n  ___   __ _  _ __    __ _  _ __  _   _ \n / __| / _` || '_ \\  / _` || '__|| | | |\n| (__ | (_| || | | || (_| || |   | |_| |\n \\___| \\__,_||_| |_| \\__,_||_|    \\__, |\n                                  |___/ \n",
    },
    {
        "font": "future_1",
        "banner": " #####   ######   ###  ##  ######   ######   ##   ##  \n##   ##   ## ###   ### ##   ## ###   ##  ##  ##   ##  \n##   ##   ##  ##   ######   ##  ##   ##  ##  ##   ##  \n##        ######   ## ###   ######   #####    ######  \n##   ##   ##  ##   ##  ##   ##  ##   ##  ##       ##  \n##   ##   ##  ##   ##  ##   ##  ##   ##  ##  ##   ##  \n #####   ###  ##  ###  ##  ###  ##  #### ###  #####   \n                                                      \n",
    },
    {
        "font": "xttyb",
        "banner": "                                   \n                                   \n                                   \n ###  ###  # ##   ###  ## ## ##  # \n##      ## ## ##    ## ##### ##  # \n##    #### ## ##  #### ##    ## ## \n##   ## ## ## ## ## ## ##     # #  \n##   ## ## ## ## ## ## ##     ###  \n ###  ## # ## ##  ## # ##      ##  \n                               #   \n                              ##   \n",
    },
    {
        "font": "jacky",
        "banner": "   ____     ____        __      _     ____     ______    __      __ \n  / ___)   (    )      /  \\    / )   (    )   (   __ \\   ) \\    / ( \n / /       / /\\ \\     / /\\ \\  / /    / /\\ \\    ) (__) )   \\ \\  / /  \n( (       ( (__) )    ) ) ) ) ) )   ( (__) )  (    __/     \\ \\/ /   \n( (        )    (    ( ( ( ( ( (     )    (    ) \\ \\  _     \\  /    \n \\ \\___   /  /\\  \\   / /  \\ \\/ /    /  /\\  \\  ( ( \\ \\_))     )(     \n  \\____) /__(  )__\\ (_/    \\__/    /__(  )__\\  )_) \\__/     /__\\    \n                                                                    \n",
    },
    {
        "font": "xbrite",
        "banner": "                                    \n                                    \n                                    \n                                    \n                                    \n ### ####  #####  ####  #### ### ## \n#  #    #   #  #     #   # #  #   # \n#     ###   #  #   ###   #    #  #  \n#    #  #   #  #  #  #   #     ###  \n ### ### # ###### ### # ###    ##   \n                               #    \n                              ##    \n",
    },
    {
        "font": "shimrod",
        "banner": "                        \n                        \n,-. ,-: ;-. ,-: ;-. . . \n|   | | | | | | |   | | \n`-' `-` ' ' `-` '   `-| \n                    `-' \n",
    },
    {
        "font": "future_2",
        "banner": " #####       ##   ##  ##       ##   #####     ##  ##  \n#######    #####  ### ##     #####  #######   ##  ##  \n##   ##    ## ##  ######     ## ##       ##   ##  ##  \n##        ##  ##  ######    ##  ##  ######     ####   \n##   ##   ######  ## ###    ######  ##   ##     ##    \n#######  ##   ##  ##  ##   ##   ##  ##   ##     ##    \n #####   ##   ##  ##  ##   ##   ##  ##   ##     ##    \n                                                      \n",
    },
    {
        "font": "nancyj-underlined",
        "banner": "                                                      \n                                                      \n.d8888b. .d8888b. 88d888b. .d8888b. 88d888b. dP    dP \n88'  `\"\" 88'  `88 88'  `88 88'  `88 88'  `88 88    88 \n88.  ... 88.  .88 88    88 88.  .88 88       88.  .88 \n`88888P' `88888P8 dP    dP `88888P8 dP       `8888P88 \noooooooooooooooooooooooooooooooooooooooooooooo~~~~.88~\n                                              d8888P  \n",
    },
    {
        "font": "crawford",
        "banner": "    __   ____  ____    ____  ____   __ __ \n   /  ] /    T|    \\  /    T|    \\ |  T  T\n  /  / Y  o  ||  _  YY  o  ||  D  )|  |  |\n /  /  |     ||  |  ||     ||    / |  ~  |\n/   \\_ |  _  ||  |  ||  _  ||    \\ l___, |\n\\     ||  |  ||  |  ||  |  ||  .  Y|     !\n \\____jl__j__jl__j__jl__j__jl__j\\_jl____/ \n                                          \n",
    },
    {
        "font": "xtimes",
        "banner": "                                   \n                                   \n                                   \n                                   \n                                   \n ###  ##   # ##    ##   ## # ## ## \n## # # ##  ## ##  # ##  #### ## ## \n##    ###  ## ##   ###  ##    ###  \n## # #  #  ## ##  #  #  ##    ###  \n ### ##### ## ### ##### ##     #   \n                             # #   \n                             ###   \n                                   \n",
    },
    {
        "font": "com_sen",
        "banner": "  ####     ###    ##   ##    ###    ######   ##   ##  \n ##  ##   ## ##   ###  ##   ## ##   ##   ##  ##   ##  \n##       ##   ##  #### ##  ##   ##  ##   ##  ##   ##  \n##       #######  ## ####  #######  ######    #####   \n##       ##   ##  ##  ###  ##   ##  #####      ###    \n ##  ##  ##   ##  ##   ##  ##   ##  ##  ##     ###    \n  ####   ##   ##  ##   ##  ##   ##  ##   ##    ###    \n                                                      \n",
    },
    {
        "font": "6x9",
        "banner": "                                          \n                                          \n                                          \n  ###    ###   ###     ###   # #    #  #  \n #      #  #   #  #   #  #   ## #   #  #  \n #      #  #   #  #   #  #   #      ## #  \n  ###    ####  #  #    ####  #        ##  \n                                    #  #  \n                                     ##   \n",
    },
    {
        "font": "64f1",
        "banner": " #####     ###    ###  ##    ###    ######   ###  ##  \n###  ##   #####   ###  ##   #####   ###  ##  ###  ##  \n##        ## ##   #### ##   ## ##   ###  ##  #######  \n##   ##  ##   ##  #######  ##   ##  #######   #####   \n###  ##  ##   ##  #######  ##   ##  ######     ###    \n#######  ## ####  ### ###  ## ####  ### ###    ###    \n#######  ## ####  ###  ##  ## ####  ### ###    ###    \n #####   ## ####  ###  ##  ## ####  ### ###    ###    \n",
    },
    {
        "font": "usa_pq",
        "banner": "                                                      \n                                                      \n #######  #######  ###  ##  #######  #######  ##   ## \n               ##  #### ##       ##       ##  ##   ## \n ##       #######  ## ####  #######  #######  ####### \n ##       ##   ##  ##  ###  ##   ##  ##  ##        ## \n #######  ##   ##  ##   ##  ##   ##  ##   ##  ####### \n                                                      \n",
    },
    {
        "font": "filter",
        "banner": "doooooo ,8b.     888  ,d8 ,8b.       ,dbPPPp 888   88 \nd88     88'8o    888_dPY8 88'8o      d88ooP' 888ooo88 \nd88     88PPY8.  8888' 88 88PPY8.  ,88' P'         88 \nd888888 8b   `Y' Y8P   Y8 8b   `Y' 88  do    PPPPPP8P \n                                                      \n",
    },
    {
        "font": "horizontalleft",
        "banner": " _______    ______   _______    ______   _______   _        \n/ _____ \\ .`  _ ._| `._   __| .`  _ ._| / ___  _| |_`.____  \n| \\   / | \\  \\_||_   _`. `._  \\  \\_||_  | \\_/  \\   .` .___| \n\\_/   \\_/  `._____| |_______|  `._____| `.__.`\\_| |_.`      \n                                                            \n                                                            \n",
    },
    {
        "font": "modular",
        "banner": " _______  _______  __    _  _______  ______   __   __ \n|       ||   _   ||  |  | ||   _   ||    _ | |  | |  |\n|       ||  |_|  ||   |_| ||  |_|  ||   | || |  |_|  |\n|       ||       ||       ||       ||   |_|| |       |\n|      _||       ||  _    ||       ||    __ ||_     _|\n|     |_ |   _   || | |   ||   _   ||   |  ||  |   |  \n|_______||__| |__||_|  |__||__| |__||___|  ||  |___|  \n",
    },
    {
        "font": "ucf_fan",
        "banner": " ####     ####    ###  #    ####     ####    ##   #   \n### ##   ### ##   ###  ##  ### ##   ### ##   ### ###  \n###      ###  ##  #### ##  ###  ##  ###  ##   #####   \n###      ###  ##  #######  ###  ##  ######     ###    \n###      #######  ### ###  #######  #####      ###    \n###  ##  ###  ##  ###  ##  ###  ##  ### ##     ###    \n #####   ###  ##  ###  ##  ###  ##  ###  ##    ###    \n                                                      \n",
    },
    {
        "font": "gothic",
        "banner": "                                    \n                                    \n       _           _                \n _-_  < \\, \\\\/\\\\  < \\, ,._-_ '\\\\/\\\\ \n||    /-|| || ||  /-||  ||    || ;' \n||   (( || || || (( ||  ||    ||/   \n\\\\,/  \\/\\\\ \\\\ \\\\  \\/\\\\  \\\\,   |/    \n                             (      \n                              -_-   \n",
    },
    {
        "font": "twin_cob",
        "banner": "                                                      \n ######   #####   ##   ##   #####   ######   ##   ##  \n###      ##   ##  ###  ##  ##   ##  ##   ##  ##   ##  \n##       #######  ## # ##  #######  ######    #####   \n###      ##   ##  ##  ###  ##   ##  ##  ##      ##    \n ######  ##   ##  ##   ##  ##   ##  ##   ##     ##    \n                                                      \n                                                      \n",
    },
    {
        "font": "smallcaps",
        "banner": " ___    _    _  _     _    ____   _  _  \n/ _(   )_\\  ) \\/ (   )_\\  /  _ \\ ) () ( \n))_   /( )\\ |  \\ |  /( )\\ )  ' / '.  /  \n\\__( )_/ \\_()_()_( )_/ \\_(|_()_\\  /_(   \n                                        \n",
    },
    {
        "font": "dancingfont",
        "banner": '   ____      _        _   _         _         ____       __   __ \nU /"___| U  /"\\  u   | \\ |"|    U  /"\\  u  U |  _"\\ u    \\ \\ / / \n\\| | u    \\/ _ \\/   <|  \\| |>    \\/ _ \\/    \\| |_) |/     \\ V /  \n | |/__   / ___ \\   U| |\\  |u    / ___ \\     |  _ <      U_|"|_u \n  \\____| /_/   \\_\\   |_| \\_|    /_/   \\_\\    |_| \\_\\       |_|   \n _// \\\\   \\\\    >>   ||   \\\\,-.  \\\\    >>    //   \\\\_  .-,//|(_  \n(__)(__) (__)  (__)  (_")  (_/  (__)  (__)  (__)  (__)  \\_) (__) \n',
    },
    {
        "font": "ascii",
        "banner": "   ####     ##     ##   ##    ##     ######   ##  ##  \n  ##  ##   ####    ###  ##   ####     ##  ##  ##  ##  \n ##       ##  ##   #### ##  ##  ##    ##  ##  ##  ##  \n ##       ##  ##   ## ####  ##  ##    #####    ####   \n ##       ######   ##  ###  ######    ## ##     ##    \n  ##  ##  ##  ##   ##   ##  ##  ##    ##  ##    ##    \n   ####   ##  ##   ##   ##  ##  ##   #### ##   ####   \n                                                      \n",
    },
    {
        "font": "nscript",
        "banner": '                                                                      \n                                                                      \n                                                                      \n                                                                      \n                                                                      \n   ,gggg,    ,gggg,gg   ,ggg,,ggg,     ,gggg,gg   ,gggggg,  gg     gg \n  dP"  "Yb  dP"  "Y8I  ,8" "8P" "8,   dP"  "Y8I   dP""""8I  I8     8I \n i8\'       i8\'    ,8I  I8   8I   8I  i8\'    ,8I  ,8\'    8I  I8,   ,8I \n,d8,_    _,d8,   ,d8b,,dP   8I   Yb,,d8,   ,d8b,,dP     Y8,,d8b, ,d8I \nP""Y8888PPP"Y8888P"`Y88P\'   8I   `Y8P"Y8888P"`Y88P      `Y8P""Y88P"888\n                                                                 ,d8I\'\n                                                               ,dP\'8I \n                                                              ,8"  8I \n                                                              I8   8I \n                                                              `8, ,8I \n                                                               `Y8P"  \n',
    },
    {
        "font": "shadow",
        "banner": "                                        \n  __|   _` |  __ \\    _` |   __|  |   | \n (     (   |  |   |  (   |  |     |   | \n\\___| \\__,_| _|  _| \\__,_| _|    \\__, | \n                                 ____/  \n",
    },
    {
        "font": "xhelvbi",
        "banner": "                                        \n                                        \n                                        \n                                        \n                                        \n  ###   ###   ####    ###   # ##  ## ## \n ## #  #  ##  ## ##  #  ##  ###   ## ## \n##      ####  #  ##   ####  ##    ## ## \n##    ## ##  ## ##  ## ##  ##      ###  \n## ## ## ##  ## ##  ## ##  ##      ##   \n ###   ## ## ## ##   ## ## ##      ##   \n                                  ##    \n                                 ##     \n",
    },
    {
        "font": "clr6x8",
        "banner": "                                          \n                                          \n  ####   ####  # ##    ####  # ##   #   # \n #      #   #  ##  #  #   #  ##     #   # \n #      #   #  #   #  #   #  #      #   # \n #      #  ##  #   #  #  ##  #       #### \n  ####   ## #  #   #   ## #  #          # \n                                     ###  \n",
    },
    {
        "font": "amcrazo2",
        "banner": "   . .       . .       . .       . .       . .       .   . \n.+'|=|`+. .+'|=|`+. .+'|=|`+. .+'|=|`+. .+'|=|`+. .+'|.+'| \n|  | `+.| |  | |  | |  | `+ | |  | |  | |  | |  | |  ||  | \n|  |      |  |=|  | |  |  | | |  |=|  | |  |'. '. `+.`'.+' \n|  |      |  | |  | |  |  | | |  | |  | |  | |  |   |  |   \n|  |    . |  | |  | |  |  | | |  | |  | |  | |  |   |  |   \n|  | .+'| |  | |  | |  |  | | |  | |  | |  | |  |   |  |   \n`+.|=|.+' `+.| |..| `+.|  |.| `+.| |..| `+.| |.+'   |.+'   \n                                                           \n",
    },
    {
        "font": "xsansbi",
        "banner": "                                         \n                                         \n                                         \n  ###   ####  ## ##   ####  ## #  ##  ## \n ##    ## ##  #####  ## ##  ####  ##  ## \n##    ##  ##  ## ## ##  ##  ##    ##  ## \n##    ## ##  ##  #  ## ##  ##     ## ##  \n##    #####  ## ##  #####  ##     ## #   \n ###  ## ##  ## ##  ## ##  ##     ###    \n                                  ##     \n                                 ##      \n",
    },
    {
        "font": "jazmine",
        "banner": "                                        \n                                        \n                                        \n.oPYo. .oPYo. odYo. .oPYo. oPYo. o    o \n8    ' .oooo8 8' `8 .oooo8 8  `' 8    8 \n8    . 8    8 8   8 8    8 8     8    8 \n`YooP' `YooP8 8   8 `YooP8 8     `YooP8 \n:.....::.....:..::..:.....:..:::::....8 \n:::::::::::::::::::::::::::::::::::ooP'.\n:::::::::::::::::::::::::::::::::::...::\n",
    },
    {
        "font": "xcourbi",
        "banner": "                                              \n                                              \n                                              \n                                              \n  ###    ###  ## ##    ###   ### ##   ### ### \n ## ##     ##  ## ##     ##   ###      ## ##  \n##      #####  ## #   #####   ##       ## #   \n## ##  ## ##  ## ##  ## ##   ##        ###    \n ###   ###### ## ### ###### ####       ##     \n                                       #      \n                                    ###       \n",
    },
    {
        "font": "smisome1",
        "banner": "    ___       ___       ___       ___       ___       ___   \n   /\\  \\     /\\  \\     /\\__\\     /\\  \\     /\\  \\     /\\__\\  \n  /::\\  \\   /::\\  \\   /:| _|_   /::\\  \\   /::\\  \\   |::L__L \n /:/\\:\\__\\ /::\\:\\__\\ /::|/\\__\\ /::\\:\\__\\ /::\\:\\__\\  |:::\\__\\\n \\:\\ \\/__/ \\/\\::/  / \\/|::/  / \\/\\::/  / \\;:::/  /  /:;;/__/\n  \\:\\__\\     /:/  /    |:/  /    /:/  /   |:\\/__/   \\/__/   \n   \\/__/     \\/__/     \\/__/     \\/__/     \\|__|            \n",
    },
    {
        "font": "alphabet",
        "banner": "                           \n                           \n ccc  aa nnn   aa rrr y  y \nc    a a n  n a a r   y  y \n ccc aaa n  n aaa r    yyy \n                         y \n                      yyy  \n",
    },
    {
        "font": "stop",
        "banner": "                                          \n                                          \n  ____   ____  ____    ____   ____  _   _ \n / ___) / _  ||  _ \\  / _  | / ___)| | | |\n( (___ ( ( | || | | |( ( | || |    | |_| |\n \\____) \\_||_||_| |_| \\_||_||_|     \\__  |\n                                   (____/ \n",
    },
    {
        "font": "battlesh",
        "banner": " ######   ####   ##   ##   ####   ######   ##  ##  \n#######  ######  ###  ##  ######  #######  ##  ##  \n###  ##  ##  ##  #### ##  ##  ##   ##  ##  ######  \n##       ##  ##  #######  ##  ##   ######   ####   \n##       ######  #######  ######   #####     ##    \n###  ##  ######  ## ####  ######   ##  ##    ##    \n#######  ##  ##  ##  ###  ##  ##  ###  ##   ####   \n ######  ##  ##  ##   ##  ##  ##  ###  ###  ####   \n",
    },
    {
        "font": "slant",
        "banner": "                                                \n  _____  ____ _   ____   ____ _   _____   __  __\n / ___/ / __ `/  / __ \\ / __ `/  / ___/  / / / /\n/ /__  / /_/ /  / / / // /_/ /  / /     / /_/ / \n\\___/  \\__,_/  /_/ /_/ \\__,_/  /_/      \\__, /  \n                                       /____/   \n",
    },
    {
        "font": "characte",
        "banner": "                                                      \n ######   ######   ##  ##   ######   ######   ##  ##  \n ##  ##   ##  ##   ### ##   ##  ##   ##  ##   ##  ##  \n ##       ##  ##   ######   ##  ##   ##  ##   ##  ##  \n ##       ######   ## ###   ######   ######   ######  \n ##  ##   ##  ##   ##  ##   ##  ##   ## ##      ##    \n ######   ##  ##   ##  ##   ##  ##   ##  ##    ####   \n                                                      \n",
    },
    {
        "font": "ghost_bo",
        "banner": " #####    #####   ##  ##    #####   #####     ##  ##  \n#######  #######  ### ##   #######  #######   ##  ##  \n##   ##  ##   ##  ######   ##   ##       ##   ##  ##  \n##       ##   ##  ######   ##   ##  ######     ####   \n##   ##  #######  ## ###   #######  ##   ##     ##    \n#######  ##   ##  ##  ##   ##   ##  ##   ##     ##    \n #####   ##   ##  ##  ##   ##   ##  ##   ##     ##    \n                                                      \n",
    },
    {
        "font": "stforek",
        "banner": "  ___   __    __  _    __    ___  __   __\n / _/  /  \\  |  \\| |  /  \\  | _ \\ \\ `v' /\n| \\__ | /\\ | | | ' | | /\\ | | v /  `. .' \n \\__/ |_||_| |_|\\__| |_||_| |_|_\\   !_!  \n",
    },
    {
        "font": "ugalympi",
        "banner": "                                                      \n  ####     ####    ##  ##    ####     #####   #   ##  \n #  ##     #  ##   ###  #    #  ##   ##  ##   ##  ##  \n #        ##  ##   # #  #   ##  ##   ##   #    ####   \n #  ##    ######   # ## #   ######   #####      ##    \n  ###     #   ##   #  ###   #   ##   ##  ##      #    \n          ##  ##   #  ###   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "1943",
        "banner": " ## ##     ##     ###  ##    ##     ### ##   ##  ##   \n##   ##     ##      ## ##     ##     ##  ##  ##  ##   \n##        ## ##    # ## #   ## ##    ##  ##  ##  ##   \n##        ##  ##   ## ##    ##  ##   ## ##    ## ##   \n##        ## ###   ##  ##   ## ###   ## ##     ##     \n##   ##   ##  ##   ##  ##   ##  ##   ##  ##    ##     \n ## ##   ###  ##  ###  ##  ###  ##  #### ##    ##     \n                                                      \n",
    },
    {
        "font": "broadway",
        "banner": "                                                                                                                  \n    ,o888888o.             .8.          b.             8          .8.          8 888888888o.   `8.`8888.      ,8' \n   8888     `88.          .888.         888o.          8         .888.         8 8888    `88.   `8.`8888.    ,8'  \n,8 8888       `8.        :88888.        Y88888o.       8        :88888.        8 8888     `88    `8.`8888.  ,8'   \n88 8888                 . `88888.       .`Y888888o.    8       . `88888.       8 8888     ,88     `8.`8888.,8'    \n88 8888                .8. `88888.      8o. `Y888888o. 8      .8. `88888.      8 8888.   ,88'      `8.`88888'     \n88 8888               .8`8. `88888.     8`Y8o. `Y88888o8     .8`8. `88888.     8 888888888P'        `8. 8888      \n88 8888              .8' `8. `88888.    8   `Y8o. `Y8888    .8' `8. `88888.    8 8888`8b             `8 8888      \n`8 8888       .8'   .8'   `8. `88888.   8      `Y8o. `Y8   .8'   `8. `88888.   8 8888 `8b.            8 8888      \n   8888     ,88'   .888888888. `88888.  8         `Y8o.`  .888888888. `88888.  8 8888   `8b.          8 8888      \n    `8888888P'    .8'       `8. `88888. 8            `Yo .8'       `8. `88888. 8 8888     `88.        8 8888      \n",
    },
    {
        "font": "epic",
        "banner": " _______  _______  _        _______  _______          \n(  ____ \\(  ___  )( (    /|(  ___  )(  ____ )|\\     /|\n| (    \\/| (   ) ||  \\  ( || (   ) || (    )|( \\   / )\n| |      | (___) ||   \\ | || (___) || (____)| \\ (_) / \n| |      |  ___  || (\\ \\) ||  ___  ||     __)  \\   /  \n| |      | (   ) || | \\   || (   ) || (\\ (      ) (   \n| (____/\\| )   ( || )  \\  || )   ( || ) \\ \\__   | |   \n(_______/|/     \\||/    )_)|/     \\||/   \\__/   \\_/   \n                                                      \n",
    },
    {
        "font": "char3",
        "banner": "   ###      ##     #    #     ##     #####     #   #  \n  #   #    #  #    ##   #    #  #    #    #    #   #  \n #        #    #   # #  #   #    #   #    #    #   #  \n #        ######   #  # #   ######   #####      ###   \n #        #    #   #   ##   #    #   #  #        #    \n  #   #   #    #   #    #   #    #   #   #       #    \n   ###    #    #   #    #   #    #   #    #      #    \n                                                      \n",
    },
    {
        "font": "krak_out",
        "banner": "                                                      \n   ####       ##  ####          ##  #######   ##   #  \n  ##  #      ###  ##  #        ###  ##    #   ##   #  \n ##         ## #  ##   #      ## #  ##   #    ######  \n##         #####  ##    #    #####  #####          #  \n##        ##   #  ##    #   ##   #  ##   #        #   \n#######  ##    #  ##    #  ##    #  ##    #   ####    \n                                                      \n",
    },
    {
        "font": "xchartr",
        "banner": "                               \n                               \n                               \n                               \n                               \n ##   ##  #####  ##  ### ## ## \n#  #   ## #   #   ## #    # #  \n#    ## # #   # ## # #    # #  \n#    #  # #   # #  # #     ##  \n ###  ### ## ##  ### ##    #   \n                           #   \n                         ##    \n",
    },
    {
        "font": "amcaaa01",
        "banner": "  sSSs   .S_SSSs     .S_sSSs     .S_SSSs     .S_sSSs     .S S.   \n d%%SP  .SS~SSSSS   .SS~YS%%b   .SS~SSSSS   .SS~YS%%b   .SS SS.  \nd%S'    S%S   SSSS  S%S   `S%b  S%S   SSSS  S%S   `S%b  S%S S%S  \nS%S     S%S    S%S  S%S    S%S  S%S    S%S  S%S    S%S  S%S S%S  \nS&S     S%S SSSS%S  S%S    S&S  S%S SSSS%S  S%S    d*S  S%S S%S  \nS&S     S&S  SSS%S  S&S    S&S  S&S  SSS%S  S&S   .S*S   SS SS   \nS&S     S&S    S&S  S&S    S&S  S&S    S&S  S&S_sdSSS     S S    \nS&S     S&S    S&S  S&S    S&S  S&S    S&S  S&S~YSY%b     SSS    \nS*b     S*S    S&S  S*S    S*S  S*S    S&S  S*S   `S%b    S*S    \nS*S.    S*S    S*S  S*S    S*S  S*S    S*S  S*S    S%S    S*S    \n SSSbs  S*S    S*S  S*S    S*S  S*S    S*S  S*S    S&S    S*S    \n  YSSP  SSS    S*S  S*S    SSS  SSS    S*S  S*S    SSS    S*S    \n               SP   SP                 SP   SP            SP     \n               Y    Y                  Y    Y             Y      \n                                                                 \n",
    },
    {
        "font": "bolger",
        "banner": '                                                    \n e88~~\\   /~~~8e  888-~88e   /~~~8e  888-~\\ Y88b  / \nd888          88b 888  888       88b 888     Y888/  \n8888     e88~-888 888  888  e88~-888 888      Y8/   \nY888    C888  888 888  888 C888  888 888       Y    \n "88__/  "88_-888 888  888  "88_-888 888      /     \n                                            _/      \n',
    },
    {
        "font": "stacey",
        "banner": "__________________________________________\n7     77  _  77     77  _  77  _  77  7  7\n|  ___!|  _  ||  _  ||  _  ||    _||  !  |\n|  7___|  7  ||  7  ||  7  ||  _ \\ !_   _!\n|     7|  |  ||  |  ||  |  ||  7  | 7   7 \n!_____!!__!__!!__!__!!__!__!!__!__! !___! \n                                          \n",
    },
    {
        "font": "utopiab",
        "banner": "                                        \n                                        \n                                        \n                                        \n ###   ###   #####    ###   ### # ## ## \n## ## ## ##   ## ##  ## ##   #### ## ## \n##     ####   ## ##   ####   ##    ###  \n###   ## ##   ## ##  ## ##   ##    ###  \n ####  ##### ### ###  ##### ####    #   \n                                  ###   \n                                  ##    \n",
    },
    {
        "font": "5x7",
        "banner": "                                    \n                                    \n ##    ###  ###    ###  ###   #  #  \n#     #  #  #  #  #  #  #  #  #  #  \n#     # ##  #  #  # ##  #      # #  \n ##    # #  #  #   # #  #       #   \n                               #    \n",
    },
    {
        "font": "colossal",
        "banner": '                                                     \n                                                     \n                                                     \n .d8888b  8888b.  88888b.   8888b.  888d888 888  888 \nd88P"        "88b 888 "88b     "88b 888P"   888  888 \n888      .d888888 888  888 .d888888 888     888  888 \nY88b.    888  888 888  888 888  888 888     Y88b 888 \n "Y8888P "Y888888 888  888 "Y888888 888      "Y88888 \n                                                 888 \n                                            Y8b d88P \n                                             "Y88P"  \n',
    },
    {
        "font": "c_consen",
        "banner": "                                                      \n                                                      \n  ####     ####    ##  ##    ####    #####    ##  ##  \n ##  ##   ##  ##   ### ##   ##  ##   ##  ##   ##  ##  \n ##       ######   ######   ######   #####     ####   \n ##  ##   ##  ##   ## ###   ##  ##   ## ##      ##    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "barbwire",
        "banner": "                                                    \n                                                    \n   ><<<   ><<    ><< ><<     ><<    >< ><<<><<   ><<\n ><<    ><<  ><<  ><<  ><< ><<  ><<  ><<    ><< ><< \n><<    ><<   ><<  ><<  ><<><<   ><<  ><<      ><<<  \n ><<   ><<   ><<  ><<  ><<><<   ><<  ><<       ><<  \n   ><<<  ><< ><<<><<<  ><<  ><< ><<<><<<      ><<   \n                                            ><<     \n",
    },
    {
        "font": "roman",
        "banner": '                                                               \n                                                               \n .ooooo.   .oooo.   ooo. .oo.    .oooo.   oooo d8b oooo    ooo \nd88\' `"Y8 `P  )88b  `888P"Y88b  `P  )88b  `888""8P  `88.  .8\'  \n888        .oP"888   888   888   .oP"888   888       `88..8\'   \n888   .o8 d8(  888   888   888  d8(  888   888        `888\'    \n`Y8bod8P\' `Y888""8o o888o o888o `Y888""8o d888b        .8\'     \n                                                   .o..P\'      \n                                                   `Y8P\'       \n                                                               \n',
    },
    {
        "font": "xbritei",
        "banner": "                                     \n                                     \n                                     \n                                     \n                                     \n  ###   ### ## ##   ### ## ##  #   # \n # #   #  #  ## #  #  #  ## #   #  # \n#     #   #  #  # #   #  #      # ## \n#     #  #  #  #  #  #  ##      ###  \n####  ##### #  ## ##### #       #    \n                                #    \n                              ##     \n",
    },
    {
        "font": "sweet",
        "banner": "                                                              \n                                                              \n  .--.      .---.   ___ .-.     .---.   ___ .-.     ___  ___  \n /    \\    / .-, \\ (   )   \\   / .-, \\ (   )   \\   (   )(   ) \n|  .-. ;  (__) ; |  |  .-. .  (__) ; |  | ' .-. ;   | |  | |  \n|  |(___)   .'`  |  | |  | |    .'`  |  |  / (___)  | |  | |  \n|  |       / .'| |  | |  | |   / .'| |  | |         | '  | |  \n|  | ___  | /  | |  | |  | |  | /  | |  | |         '  `-' |  \n|  '(   ) ; |  ; |  | |  | |  ; |  ; |  | |          `.__. |  \n'  `-' |  ' `-'  |  | |  | |  ' `-'  |  | |          ___ | |  \n `.__,'   `.__.'_. (___)(___) `.__.'_. (___)        (   )' |  \n                                                     ; `-' '  \n                                                      .__.'   \n",
    },
    {
        "font": "fp2",
        "banner": " #####   ######   ###  ##  ######   ######   ##   ##  \n##   ##   ## ###   ### ##   ## ###   ##  ##  ##   ##  \n##   ##   ##  ##   ######   ##  ##   ##  ##  ##   ##  \n##        ######   ## ###   ######   #####    ######  \n##   ##   ##  ##   ##  ##   ##  ##   ##  ##       ##  \n##   ##   ##  ##   ##  ##   ##  ##   ##  ##  ##   ##  \n #####   ###  ##  ###  ##  ###  ##  #### ###  #####   \n                                                      \n",
    },
    {
        "font": "grand_pr",
        "banner": "  ##       ##     ##  ##     ##     ####     ##  ##   \n##  ##   ##  ##   ##  ##   ##  ##   ##  ##   ##  ##   \n##       ##  ##   ######   ##  ##   ##  ##   ##  ##   \n##       ######   ######   ######   ####       ##     \n##       ##  ##   ##  ##   ##  ##   ##  ##     ##     \n##  ##   ##  ##   ##  ##   ##  ##   ##  ##     ##     \n  ##     ##  ##   ##  ##   ##  ##   ##  ##     ##     \n                                                      \n",
    },
    {
        "font": "poison",
        "banner": "                                                           \n @@@@@@@   @@@@@@   @@@  @@@   @@@@@@   @@@@@@@   @@@ @@@  \n@@@@@@@@  @@@@@@@@  @@@@ @@@  @@@@@@@@  @@@@@@@@  @@@ @@@  \n!@@       @@!  @@@  @@!@!@@@  @@!  @@@  @@!  @@@  @@! !@@  \n!@!       !@!  @!@  !@!!@!@!  !@!  @!@  !@!  @!@  !@! @!!  \n!@!       @!@!@!@!  @!@ !!@!  @!@!@!@!  @!@!!@!    !@!@!   \n!!!       !!!@!!!!  !@!  !!!  !!!@!!!!  !!@!@!      @!!!   \n:!!       !!:  !!!  !!:  !!!  !!:  !!!  !!: :!!     !!:    \n:!:       :!:  !:!  :!:  !:!  :!:  !:!  :!:  !:!    :!:    \n ::: :::  ::   :::   ::   ::  ::   :::  ::   :::     ::    \n :: :: :   :   : :  ::    :    :   : :   :   : :     :     \n                                                           \n",
    },
    {
        "font": "inc_raw",
        "banner": "##     # ##     # ## ##  # ##     # ##     # ## ##  # \n#  ##  # #  ##  # #  ##  # #  ##  # #  ##  # #  ##  # \n#  ##### #  ##  # #   #  # #  ##  # #  ##  # #  ##  # \n#  ##### #      # #      # #      # #     ## ##    ## \n#  ##### #  ##  # #      # #  ##  # #    ### ###  ### \n#  ##### #  ##  # #  #   # #  ##  # #  #  ## ###  ### \n#  ##  # #  ##  # #  ##  # #  ##  # #  #  ## ###  ### \n#     ## #  ## ## #  ## ## #  ## ## #  #  ## ### #### \n",
    },
    {
        "font": "amcrazor",
        "banner": "       ___                    ___                     __   ___   ___  \n  .'|=|_.'   .'|=|`.     .'| |   |   .'|=|`.     .'|=|  | |   | |   | \n.'  |      .'  | |  `. .'  |\\|   | .'  | |  `. .'  | |  | `.  |_|  .' \n|   |      |   |=|   | |   | |   | |   |=|   | |   |=|.'    `.   .'   \n`.  |  ___ |   | |   | |   | |  .' |   | |   | |   |  |`.    |   |    \n  `.|=|_.' |___| |___| |___| |.'   |___| |___| |___|  |_|    |___|    \n                                                                      \n",
    },
    {
        "font": "goofy",
        "banner": "__    ______  _____     ___    _____  _____     ____   __   __\n /  __)    /  \\    |    \\  |  |    /  \\    |    \\  (  (  )  ) \n|  /      /    \\   |  |\\ \\ |  |   /    \\   |     )  \\  \\/  /  \n| |      /  ()  \\  |  | \\ \\|  |  /  ()  \\  |    /    \\    /   \n|  \\__  |   __   | |  |  \\    | |   __   | | |\\ \\     )  /    \n_\\    )_|  (__)  |_|  |___\\   |_|  (__)  |_| |_\\ \\___/  (_____\n",
    },
    {
        "font": "small",
        "banner": "                                 \n __  __ _  _ _   __ _  _ _  _  _ \n/ _|/ _` || ' \\ / _` || '_|| || |\n\\__|\\__,_||_||_|\\__,_||_|   \\_, |\n                            |__/ \n",
    },
    {
        "font": "a_zooloo",
        "banner": " #####     ###    ##  ##     ###    ######    ## ##   \n#######   #####   ### ###   #####   ### ###  ### ###  \n### # #  ### ###  ### ###  ### ###  ###  ##  ### ###  \n##       ### ###  #### ##  ### ###  ### ###  #######  \n##       ### ###  ## ####  ### ###  ######    ## ###  \n### # #  #######  ### ###  #######  ### ###      ###  \n#######  ### ###  ### ###  ### ###   ### ### #######  \n #####    ##  ##   ##  ##   ##  ##   ### ###  #####   \n",
    },
    {
        "font": "oldbanner",
        "banner": "                                         \n ####    ##   #    #   ##   #####  #   # \n#    #  #  #  ##   #  #  #  #    #  # #  \n#      #    # # #  # #    # #    #   #   \n#      ###### #  # # ###### #####    #   \n#    # #    # #   ## #    # #   #    #   \n ####  #    # #    # #    # #    #   #   \n",
    },
    {
        "font": "defleppard",
        "banner": "                                                                            \n                                                                            \n       .,               L.                                                  \n      ,Wt               EW:        ,ft               j.                     \n     i#D.            .. E##;       t#E            .. EW,         f.     ;WE.\n    f#f             ;W, E###t      t#E           ;W, E##j        E#,   i#G  \n  .D#i             j##, E#fE#f     t#E          j##, E###D.      E#t  f#f   \n :KW,             G###, E#t D#G    t#E         G###, E#jG#W;     E#t G#i    \n t#f            :E####, E#t  f#E.  t#E       :E####, E#t t##f    E#jEW,     \n  ;#G          ;W#DG##, E#t   t#K: t#E      ;W#DG##, E#t  :K#E:  E##E.      \n   :KE.       j###DW##, E#t    ;#W,t#E     j###DW##, E#KDDDD###i E#G        \n    .DW:     G##i,,G##, E#t     :K#D#E    G##i,,G##, E#f,t#Wi,,, E#t        \n      L#,  :K#K:   L##, E#t      .E##E  :K#K:   L##, E#t  ;#W:   E#t        \n       jt ;##D.    L##, ..         G#E ;##D.    L##, DWi   ,KK:  EE.        \n          ,,,      .,,              fE ,,,      .,,              t          \n                                     ,                                      \n",
    },
    {
        "font": "chunky",
        "banner": "                                        \n.----..---.-..-----..---.-..----..--.--.\n|  __||  _  ||     ||  _  ||   _||  |  |\n|____||___._||__|__||___._||__|  |___  |\n                                 |_____|\n",
    },
    {
        "font": "isometric4",
        "banner": "      ___           ___           ___           ___           ___                   \n     /  /\\         /  /\\         /  /\\         /  /\\         /  /\\          __      \n    /  /::\\       /  /::\\       /  /::|       /  /::\\       /  /::\\        |  |\\    \n   /  /:/\\:\\     /  /:/\\:\\     /  /:|:|      /  /:/\\:\\     /  /:/\\:\\       |  |:|   \n  /  /:/  \\:\\   /  /::\\ \\:\\   /  /:/|:|__   /  /::\\ \\:\\   /  /::\\ \\:\\      |  |:|   \n /__/:/ \\  \\:\\ /__/:/\\:\\_\\:\\ /__/:/ |:| /\\ /__/:/\\:\\_\\:\\ /__/:/\\:\\_\\:\\     |__|:|__ \n \\  \\:\\  \\__\\/ \\__\\/  \\:\\/:/ \\__\\/  |:|/:/ \\__\\/  \\:\\/:/ \\__\\/~|::\\/:/     /  /::::\\\n  \\  \\:\\            \\__\\::/      |  |:/:/       \\__\\::/     |  |:|::/     /  /:/~~~~\n   \\  \\:\\           /  /:/       |__|::/        /  /:/      |  |:|\\/     /__/:/     \n    \\  \\:\\         /__/:/        /__/:/        /__/:/       |__|:|~      \\__\\/      \n     \\__\\/         \\__\\/         \\__\\/         \\__\\/         \\__\\|                  \n",
    },
    {
        "font": "amctubes",
        "banner": "  sSSs. d s.   d s  b d s.   d ss.  Ss   sS \n S      S  ~O  S  S S S  ~O  S    b   S S   \nS       S   `b S   SS S   `b S    P    S    \nS       S sSSO S    S S sSSO S sS'     S    \nS       S    O S    S S    O S   S     S    \n S      S    O S    S S    O S    S    S    \n  \"sss' P    P P    P P    P P    P    P    \n                                            \n",
    },
    {
        "font": "clr6x10",
        "banner": "                                          \n                                          \n                                          \n  ####   ####  # ##    ####  # ##   #   # \n #      #   #  ##  #  #   #  ##     #   # \n #      #   #  #   #  #   #  #      #   # \n #      #  ##  #   #  #  ##  #      #   # \n  ####   ## #  #   #   ## #  #       #### \n                                        # \n                                     ###  \n",
    },
    {
        "font": "ogre",
        "banner": "                                        \n  ___   __ _  _ __    __ _  _ __  _   _ \n / __| / _` || '_ \\  / _` || '__|| | | |\n| (__ | (_| || | | || (_| || |   | |_| |\n \\___| \\__,_||_| |_| \\__,_||_|    \\__, |\n                                  |___/ \n",
    },
    {
        "font": "hyper",
        "banner": "  ####     ###    ##   ##    ###    ######    ##  ##  \n ##  ##   ## ##   ###  ##   ## ##   ##   ##   ##  ##  \n##       ##   ##  #### ##  ##   ##  ##   ##    #  #   \n##       ##   ##  #######  ##   ##  ##  ###    ####   \n##       #######  ## ####  #######  #####       ##    \n ##  ##  ##   ##  ##  ###  ##   ##  ## ###      ##    \n  ####   ##   ##  ##   ##  ##   ##  ##  ###     ##    \n                                                      \n",
    },
    {
        "font": "rectangles",
        "banner": "                              \n                              \n ___  ___  ___  ___  ___  _ _ \n|  _|| .'||   || .'||  _|| | |\n|___||__,||_|_||__,||_|  |_  |\n                         |___|\n",
    },
    {
        "font": "atc",
        "banner": "#        ######   #  ##    ######   #        #   #    \n#   ##   #####    #   ##   #####    #   ##   #   #    \n#   #### ####     #    #   ####     #   ##   #   #    \n#   #### ###  #   #        ###  #   #      # ##     # \n#   #### ##       #  #     ##       #   #    ###   ## \n#   ##   #   ##   #  ##    #   ##   #   #    ###   ## \n#           ###   #   ##      ###   #   #    ###   ## \n######## ######## ######## ######## ######## ######## \n",
    },
    {
        "font": "rammstein",
        "banner": "                                                       \n ______   ____     ____   _   ____     _____   __    _ \n|   ___| |    \\   |    \\ | | |    \\   |     |  \\ \\  // \n|   |__  |     \\  |     \\| | |     \\  |     \\   \\ \\//  \n|______| |__|\\__\\ |__/\\____| |__|\\__\\ |__|\\__\\  /__/   \n                                                       \n                                                       \n",
    },
    {
        "font": "e_fist",
        "banner": "  ####     ####    ##  ##    ####    #####    ##  ##  \n ##  ##   ##  ##   ##  ##   ##  ##   ##  ##   ##  ##  \n ##       ##  ##   ### ##   ##  ##   ##  ##   ##  ##  \n ##       ######   ######   ######   #####     ####   \n ##       ##  ##   ## ###   ##  ##   ## ##      ##    \n ##  ##   ##  ##   ##  ##   ##  ##   ##  ##     ##    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "speed",
        "banner": "                                                \n_____________ ________ ______ ______________  __\n_  ___/_  __ `/__  __ \\_  __ `/__  ___/__  / / /\n/ /__  / /_/ / _  / / // /_/ / _  /    _  /_/ / \n\\___/  \\__,_/  /_/ /_/ \\__,_/  /_/     _\\__, /  \n                                       /____/   \n",
    },
    {
        "font": "knob",
        "banner": " _________  _________  _________  _________  _________      _____ \n(  _____  )(____  _  )(______  _)(____  _  )(___   _  ) ___/  ___)\n| |     | | ___| |_| | _____/ /_  ___| |_| | _/   |_| |(___  (___ \n(_)     (_)(_________)(_________)(_________)(__/(_____)    \\_____)\n",
    },
    {
        "font": "dotmatrix",
        "banner": "                                                                                                            \n                                                                                                            \n   _  _  _          _  _  _         _  _  _  _         _  _  _         _       _  _      _               _  \n _(_)(_)(_)        (_)(_)(_) _     (_)(_)(_)(_)_      (_)(_)(_) _     (_)_  _ (_)(_)    (_)_           _(_) \n(_)                 _  _  _ (_)    (_)        (_)      _  _  _ (_)      (_)(_)            (_)_       _(_)   \n(_)               _(_)(_)(_)(_)    (_)        (_)    _(_)(_)(_)(_)      (_)                 (_)_   _(_)     \n(_)_  _  _       (_)_  _  _ (_)_   (_)        (_)   (_)_  _  _ (_)_     (_)                   (_)_(_)       \n  (_)(_)(_)        (_)(_)(_)  (_)  (_)        (_)     (_)(_)(_)  (_)    (_)                    _(_)         \n                                                                                          _  _(_)           \n                                                                                         (_)(_)             \n",
    },
    {
        "font": "nipples",
        "banner": "                                                    \n                                                    \n   {___   {__    {__ {__     {__    {_ {___{__   {__\n {__    {__  {__  {__  {__ {__  {__  {__    {__ {__ \n{__    {__   {__  {__  {__{__   {__  {__      {___  \n {__   {__   {__  {__  {__{__   {__  {__       {__  \n   {___  {__ {___{___  {__  {__ {___{___      {__   \n                                            {__     \n",
    },
    {
        "font": "banner",
        "banner": "                                         \n ####    ##   #    #   ##   #####  #   # \n#    #  #  #  ##   #  #  #  #    #  # #  \n#      #    # # #  # #    # #    #   #   \n#      ###### #  # # ###### #####    #   \n#    # #    # #   ## #    # #   #    #   \n ####  #    # #    # #    # #    #   #   \n                                         \n",
    },
    {
        "font": "future_3",
        "banner": " #######  ######   ###  ##  ######   ######   ###  ## \n               ##   ### ##       ##       ##   ##  ## \n  ##       ##  ##   ######   ##  ##   ##  ##    #  ## \n  ##       ######   ## ###   ######   #####     ####  \n  ##       ##  ##   ##  ##   ##  ##   ##  ##     ##   \n  ##       ##  ##   ##  ##   ##  ##   ##  ##    ##    \n  ######   ##  ##   ##  ##   ##  ##   ##  ##  # #     \n                                                      \n",
    },
    {
        "font": "charact5",
        "banner": "                                                      \n  #####   #####    ##  ##   #####   ######    ##  ##  \n ### ##   #####    ### ##   #####    ######   ##  ##  \n ###      ## ##    ######   ## ##    ##  ##   ######  \n ###      #####    ######   #####    #####     ####   \n ### ##   ## ##    ## ###   ## ##    #####      ##    \n  #####  ### ###   ##  ##  ### ###   ##  ##    ####   \n                                                      \n",
    },
    {
        "font": "merlin2",
        "banner": "    _          _        _           _        _              _  \n __/\\\\___   __/\\\\__   _/\\\\___    __/\\\\__   _/\\\\___     _   /\\\\ \n(_  ____)) (_  ____) (_      )) (_  ____) (_   _  ))  /\\\\ / // \n /  ||      /  _ \\\\   /  :   \\\\  /  _ \\\\   /  |))//   \\ \\/ //  \n/:. ||___  /:./_\\ \\\\ /:. |   // /:./_\\ \\\\ /:.    \\\\   _\\:.//   \n\\  _____)) \\  _   // \\___|  //  \\  _   // \\___|  //  (_  _))   \n \\//        \\// \\//       \\//    \\// \\//       \\//     \\//     \n                                                               \n                                                               \n",
    },
    {
        "font": "ebbs_2",
        "banner": "  ####     ###    ##   ##    ###    ######   ##   ##  \n ##  ##   ## ##   ###  ##   ## ##   ##   ##  ##   ##  \n##       ##   ##  #### ##  ##   ##  ##   ##  ##   ##  \n##       #######  ## ####  #######  ######    #####   \n##       ##   ##  ##  ###  ##   ##  #####      ###    \n ##  ##  ##   ##  ##   ##  ##   ##  ##  ##     ###    \n  ####   ##   ##  ##   ##  ##   ##  ##   ##    ###    \n                                                      \n",
    },
    {
        "font": "nfi1",
        "banner": "##                                      ####          \n##                                        ##          \n##                      ##                            \n##                                                    \n                                                      \n                                          ## ##       \n##                                      #### ##       \n                                                      \n",
    },
    {
        "font": "ghoulish",
        "banner": "   )\\.-.     /`-.    )\\  )\\     /`-.      /`-.  )\\    /( \n ,' ,-,_)  ,' _  \\  (  \\, /   ,' _  \\   ,' _  \\ \\ (_.' / \n(  .   _  (  '-' (   ) \\ (   (  '-' (  (  '-' (  )  _.'  \n ) '..' )  )   _  ) ( ( \\ \\   )   _  )  ) ,_ .'  / /     \n(  ,   (  (  ,' ) \\  `.)/  ) (  ,' ) \\ (  ' ) \\ (  \\     \n )/'._.'   )/    )/     '.(   )/    )/  )/   )/  ).'     \n                                                         \n",
    },
    {
        "font": "xhelv",
        "banner": "                                \n                                \n                                \n                                \n                                \n ##  ###   # ##  ###   # # #  # \n#  #    #  ##  #    #  ##  #  # \n#     ###  #   #  ###  #   # #  \n#    #  #  #   # #  #  #   # #  \n#  # #  #  #   # #  #  #    ##  \n ##   ## # #   #  ## # #    #   \n                            #   \n                           #    \n",
    },
    {
        "font": "coil_cop",
        "banner": "  ####     ###    ##   ##    ###    ######   ###  ### \n ##  ##   ## ##   ###  ##   ## ##    ##  ##   ##  ##  \n##       ##   ##  #### ##  ##   ##   ##  ##    ####   \n##       ##   ##  #######  ##   ##   #####      ##    \n##       #######  ## ####  #######   ## ##      ##    \n ##  ##  ##   ##  ##  ###  ##   ##   ## ##      ##    \n  ####   ##   ##  ##   ##  ##   ##  #### ##    ####   \n                                                      \n",
    },
    {
        "font": "beer_pub",
        "banner": " #####    #####   ##  ###   #####   ######   ### ###  \n### ###  ### ###  ### ###  ### ###  ### ###  ### ###  \n###      ### ###  #######  ### ###  ### ###  ### ###  \n###      #######  #######  #######  ######    #####   \n###      ### ###  ### ###  ### ###  ### ##     ###    \n### ###  ### ###  ### ###  ### ###  ### ###    ###    \n #####   ### ###  ### ###  ### ###  ### ###    ###    \n                                                      \n",
    },
    {
        "font": "funface",
        "banner": "   c  c          \\\\\\  ///          ))     wWw  wWw \n   (OO)     /)   ((O)(O))    /)   (Oo)-.  (O)  (O) \n ,'.--.)  (o)(O)  | \\ ||   (o)(O)  | (_)) ( \\  / ) \n/ //_|_\\   //\\\\   ||\\\\||    //\\\\   |  .'   \\ \\/ /  \n| \\___    |(__)|  || \\ |   |(__)|  )|\\\\     \\o /   \n'.    )   /,-. |  ||  ||   /,-. | (/  \\)   _/ /    \n  `-.'   -'   '' (_/  \\_) -'   ''  )      (_.'     \n",
    },
    {
        "font": "tanja",
        "banner": "                                                \n                                                \n c)CCCC a)AAAA  n)NNNN  a)AAAA   r)RRR  y)   YY \nc)       a)AAA  n)   NN  a)AAA  r)   RR y)   YY \nc)      a)   A  n)   NN a)   A  r)      y)   YY \n c)CCCC  a)AAAA n)   NN  a)AAAA r)       y)YYYY \n                                             y) \n                                        y)YYYY  \n",
    },
    {
        "font": "soft",
        "banner": "                                                    \n                                                    \n ,---.  ,--,--. ,--,--,   ,--,--. ,--.--. ,--. ,--. \n| .--' ' ,-.  | |      \\ ' ,-.  | |  .--'  \\  '  /  \n\\ `--. \\ '-'  | |  ||  | \\ '-'  | |  |      \\   '   \n `---'  `--`--' `--''--'  `--`--' `--'    .-'  /    \n                                          `---'     \n",
    },
    {
        "font": "3-d",
        "banner": "                                                     \n                                              **   **\n  *****   ******   *******   ******   ****** //** ** \n **///** //////** //**///** //////** //**//*  //***  \n/**  //   *******  /**  /**  *******  /** /    /**   \n/**   ** **////**  /**  /** **////**  /**      **    \n//***** //******** ***  /**//********/***     **     \n /////   //////// ///   //  //////// ///     //      \n",
    },
    {
        "font": "xbritebi",
        "banner": "                                         \n                                         \n                                         \n                                         \n  ###   #### ### ##   #### ## ##  ##  ## \n # #   #  ##  # # #  #  ##  ##     ##  # \n#     #   #   ##  # #   #   ##     ## ## \n#     # ###   #  #  # ###   #      ####  \n####  ###### ##  ## ###### #        #    \n                                   #     \n                                 ##      \n",
    },
    {
        "font": "graceful",
        "banner": "  ___   __   __ _   __   ____  _  _ \n / __) / _\\ (  ( \\ / _\\ (  _ \\( \\/ )\n( (__ /    \\/    //    \\ )   / )  / \n \\___)\\_/\\_/\\_)__)\\_/\\_/(__\\_)(__/  \n",
    },
    {
        "font": "avatar",
        "banner": " ____  ____  _      ____  ____ ___  _\n/   _\\/  _ \\/ \\  /|/  _ \\/  __\\\\  \\//\n|  /  | / \\|| |\\ ||| / \\||  \\/| \\  / \n|  \\_ | |-||| | \\||| |-|||    / / /  \n\\____/\\_/ \\|\\_/  \\|\\_/ \\|\\_/\\_\\/_/   \n                                     \n",
    },
    {
        "font": "fp1",
        "banner": " #######  ######   ###  ##  ######   ######   ###  ## \n               ##   ### ##       ##       ##   ##  ## \n  ##       ##  ##   ######   ##  ##   ##  ##   ##  ## \n  ##       ######   ## ###   ######   #####     ####  \n  ##       ##  ##   ##  ##   ##  ##   ##  ##     ##   \n  ##       ##  ##   ##  ##   ##  ##   ##  ##    ##    \n  ######   ##  ##   ##  ##   ##  ##   ##  ##  ###     \n                                                      \n",
    },
    {
        "font": "letters",
        "banner": "                                              \n  cccc   aa aa nn nnn    aa aa rr rr  yy   yy \ncc      aa aaa nnn  nn  aa aaa rrr  r yy   yy \ncc     aa  aaa nn   nn aa  aaa rr      yyyyyy \n ccccc  aaa aa nn   nn  aaa aa rr          yy \n                                       yyyyy  \n",
    },
    {
        "font": "funky_dr",
        "banner": "                                                      \n                                                      \n ######   #####    #####    #####    #####   ##  ##   \n##       ##   ##  ##   ##  ##   ##  ##   ##  ##  ##   \n##       ## ####  ##   ##  ## ####  ## ###    ####    \n##       ##   ##  ##   ##  ##   ##  ##   ##    ##     \n ######  ##   ##  ##   ##  ##   ##  ##   ##    ##     \n                                                      \n",
    },
    {
        "font": "katakana",
        "banner": "           #          ######   #                    \n           #   ###             #   ###  #########   \n  ##       ####     ########## ####     #       #   \n #  ##     #        #        # #        #       #   \n#     ##   #               ##  #        #       #   \n        ## #             ##    #        #########   \n            #######    ##       #######             \n                                                    \n",
    },
    {
        "font": "xsansi",
        "banner": "                                   \n                                   \n                                   \n  ##   ###  # ##   ###  # #   #  # \n #    #  #  ## #  #  #  ###   #  # \n#    #   #  #  # #   #  #     #  # \n#    #  #  #  #  #  #  #      # #  \n#    # ##  #  #  # ##  #      # #  \n ##  ## #  #  #  ## #  #      ##   \n                              #    \n                            ##     \n",
    },
    {
        "font": "clb8x8",
        "banner": "                                                      \n                                                      \n  #####    ######  ## ###    ######  ## ###   ##  ##  \n ##       ##   ##  ###  ##  ##   ##  ###      ##  ##  \n ##       ##   ##  ##   ##  ##   ##  ##       ##  ##  \n ##       ##  ###  ##   ##  ##  ###  ##        #####  \n  #####    ### ##  ##   ##   ### ##  ##           ##  \n                                               ####   \n",
    },
    {
        "font": "vortron",
        "banner": "   ####     ##     ##   ##    ##       ####   ##   ## \n  ##  ##   ####    ###  ##   ####     ##  ##  ##  ##  \n ##        ## ##   #### ##   ## ##   ##   ##  ## ##   \n ##       ##   ##  #######  ##   ##  ######    ###    \n ##   ##  #######  ## ####  #######  ####       ##    \n ##  ##   ##   ##  ##  ###  ##   ##  ## ##      ##    \n  ####    ##   ##  ##   ##  ##   ##  ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "fbr_stri",
        "banner": "  ####    ######   ##  ##   ######   #####    ##  ##  \n ######   ######   ### ##   ######   ######   ##  ##  \n ##  ##   ##  ##   ## ###   ##  ##   ##   #    #  #   \n ##       ##  ##   ##  ##   ##  ##   ##   #    #  #   \n ##       ######   ##  ##   ######   #####      ##    \n ##  ##   ##  ##   ##  ##   ##  ##   ##   #     ##    \n  ####    ##  ##   ##  ##   ##  ##   ##   #     ##    \n                                                      \n",
    },
    {
        "font": "smslant",
        "banner": "                                    \n ____ ___ _  ___  ___ _  ____  __ __\n/ __// _ `/ / _ \\/ _ `/ / __/ / // /\n\\__/ \\_,_/ /_//_/\\_,_/ /_/    \\_, / \n                             /___/  \n",
    },
    {
        "font": "clr5x8",
        "banner": "                                    \n                                    \n  ###   ###  ###    ###  # ##  #  # \n #     #  #  #  #  #  #  ##    #  # \n #     #  #  #  #  #  #  #     #  # \n #     # ##  #  #  # ##  #      ### \n  ###   # #  #  #   # #  #        # \n                                ##  \n",
    },
    {
        "font": "fraktur",
        "banner": '                                                                          \n                                                               ..         \n                         u.    u.                  .u    .    @L          \n      .         u      x@88k u@88c.       u      .d88B :@8c  9888i   .dL  \n .udR88N     us888u.  ^"8888""8888"    us888u.  ="8888f8888r `Y888k:*888. \n<888\'888k .@88 "8888"   8888  888R  .@88 "8888"   4888>\'88"    888E  888I \n9888 \'Y"  9888  9888    8888  888R  9888  9888    4888> \'      888E  888I \n9888      9888  9888    8888  888R  9888  9888    4888>        888E  888I \n9888      9888  9888    8888  888R  9888  9888   .d888L .+     888E  888I \n?8888u../ 9888  9888   "*88*" 8888" 9888  9888   ^"8888*"     x888N><888\' \n "8888P\'  "888*""888"    ""   \'Y"   "888*""888"     "Y"        "88"  888  \n   "P\'     ^Y"   ^Y\'                 ^Y"   ^Y\'                       88F  \n                                                                    98"   \n                                                                  ./"     \n                                                                 ~`       \n',
    },
    {
        "font": "asc",
        "banner": "                                                      \n                                                      \n #######  #######  #     #  #######  #######  #     # \n #        #     #  ##    #  #     #  #     #  #     # \n #        #######  # ### #  #######  #######  ####### \n #        #     #  #    ##  #     #  #    #         # \n #######  #     #  #     #  #     #  #    ##  ####### \n                                                      \n",
    },
    {
        "font": "xcourb",
        "banner": "                                          \n                                          \n                                          \n                                          \n ###   ###   ## ##   ###   ## ### ### ### \n## ## ## ##   ## ## ## ##   ### #  ## ##  \n##     ####   ## ##  ####   ##     ## ##  \n## ## ## ##   ## ## ## ##   ##      # #   \n ###  ######  ## ## ###### ####     ###   \n                                    ##    \n                                  ####    \n",
    },
    {
        "font": "fbr_tilt",
        "banner": "    ###      ###   #    #      ###      ###    #  ##  \n   ####     ####  ##   ##     ####     ####   ##  ##  \n  ##  #    ## ##  ###  ##    ## ##    ## ##  ### ##   \n ##       ##  ##  #### ##   ##  ##   ##  ##    ###    \n##       #######  ## ####  #######  #####       ##    \n##    #  ##   ##  ##  ###  ##   ##  ##  ##      ##    \n#######  ##   ##  ##   ##  ##   ##  ##   ##     ###   \n                                               ##     \n",
    },
    {
        "font": "fbr12",
        "banner": "    ###      ###   #    #      ###      ###    #  ##  \n   ####     ####  ##   ##     ####     ####   ##  ##  \n  ##  #    ## ##  ###  ##    ## ##    ## ##  ### ##   \n ##       ##  ##  #### ##   ##  ##   ##  ##    ###    \n##       #######  ## ####  #######  #####       ##    \n##    #  ##   ##  ##  ###  ##   ##  ##  ##      ##    \n#######  ##   ##  ##   ##  ##   ##  ##   ##     ###   \n                                               ##     \n",
    },
    {
        "font": "braced",
        "banner": ".----.   .--.   .-. .-.   .--.   .---.  .-.  .-. \n| }`-'  / {} \\  |  \\{ |  / {} \\  } }}_}  \\ \\/ /  \n| },-. /  /\\  \\ | }\\  { /  /\\  \\ | } \\    `-\\ }  \n`----' `-'  `-' `-' `-' `-'  `-' `-'-'      `-'  \n                                                 \n",
    },
    {
        "font": "tsn_base",
        "banner": "                                                      \n  ####     ####    ##  ##    ####    #####    ##  ##  \n ##  ##   ##  ##   ### ##   ##  ##   ##  ##   ##  ##  \n ##       ######   ######   ######   #####     ####   \n ##  ##   ##  ##   ## ###   ##  ##   ##  ##     ##    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##     ##    \n                                                      \n                                                      \n",
    },
    {
        "font": "5lineoblique",
        "banner": "                                                                \n                                                                \n                                                                \n    ___        ___         __        ___        __              \n  //   ) )   //   ) )   //   ) )   //   ) )   //  ) )  //   / / \n //         //   / /   //   / /   //   / /   //       ((___/ /  \n((____     ((___( (   //   / /   ((___( (   //            / /   \n",
    },
    {
        "font": "slide",
        "banner": "                                    \n #HH| ##|   ##H|  ##|   ## H| ## H| \n##      H|  ## H|   H|  ##H|  ## H| \n##    ##H|  ## H| ##H|  ##     #HH| \n #HH| ##HH| ## H| ##HH| ##       H| \n                              ##H|  \n",
    },
    {
        "font": "serifcap",
        "banner": "  __   __   _  _   __   ___   _  _ \n / _) (  ) ( \\( ) (  ) (  ,) ( \\/ )\n( (_  /__\\  )  (  /__\\  )  \\  \\  / \n \\__)(_)(_)(_)\\_)(_)(_)(_)\\_)(__/  \n",
    },
    {
        "font": "clr8x10",
        "banner": "                                                      \n                                                      \n                                                      \n  #####    ######  # ####    ######   # ###   #    #  \n #        #     #  ##    #  #     #   ##      #    #  \n #        #     #  #     #  #     #   #       #    #  \n #        #    ##  #     #  #    ##   #       #    #  \n  #####    #### #  #     #   #### #   #        #####  \n                                                   #  \n                                               ####   \n",
    },
    {
        "font": "flipped",
        "banner": " ____  ___   ____  ___   ____     _ \n| _  ||_  \\ |__  ||_  \\ |_   | __/ |\n| ||_| _|> | _/ /  _|> | / | ||__ < \n|_|   |___/ |____||___/ |/\\__/   \\_|\n",
    },
    {
        "font": "chiseled",
        "banner": "   _,.----.      ,---.       .-._            ,---.                                    \n .' .' -   \\   .--.'  \\     /==/ \\  .-._   .--.'  \\       .-.,.---.    ,--.-.  .-,--. \n/==/  ,  ,-'   \\==\\-/\\ \\    |==|, \\/ /, /  \\==\\-/\\ \\     /==/  `   \\  /==/- / /=/_ /  \n|==|-   |  .   /==/-|_\\ |   |==|-  \\|  |   /==/-|_\\ |   |==|-, .=., | \\==\\, \\/=/. /   \n|==|_   `-' \\  \\==\\,   - \\  |==| ,  | -|   \\==\\,   - \\  |==|   '='  /  \\==\\  \\/ -/    \n|==|   _  , |  /==/ -   ,|  |==| -   _ |   /==/ -   ,|  |==|- ,   .'    |==|  ,_/     \n\\==\\.       / /==/-  /\\ - \\ |==|  /\\ , |  /==/-  /\\ - \\ |==|_  . ,'.    \\==\\-, /      \n `-.`.___.-'  \\==\\ _.\\=\\.-' /==/, | |- |  \\==\\ _.\\=\\.-' /==/  /\\ ,  )   /==/._/       \n               `--`         `--`./  `--`   `--`         `--`-`--`--'    `--`-`        \n",
    },
    {
        "font": "thick",
        "banner": "                                 \n.d8b .d88 8d8b. .d88 8d8b Yb  dP \n8    8  8 8P Y8 8  8 8P    YbdP  \n`Y8P `Y88 8   8 `Y88 8      dP   \n                           dP    \n",
    },
    {
        "font": "ebbs_1",
        "banner": "                                                      \n  ####      ##     ##  ##     ##     #####    ##  ##  \n ##  ##    ####    ### ##    ####    ##  ##   ##  ##  \n ##       ##  ##   ######   ##  ##   ##  ##    ####   \n ##       ######   ## ###   ######   #####      ##    \n ##  ##   ##  ##   ##  ##   ##  ##   ## ##      ##    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "charact4",
        "banner": "                                                      \n ######    ####    ##  ##    ####    ######   ##  ##  \n ## ###    ####    ### ##    ####    ## ###   ##  ##  \n ##       ##  ##   ######   ##  ##   ## ###   ######  \n ##       ######   ######   ######   #####    ######  \n ##  ##   ##  ##   ### ##   ##  ##   ## ###     ##    \n ######   ##  ##   ### ##   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "wetletter",
        "banner": "  ,--,     .--.    .-. .-.   .--.   ,---.    .-.   .-.\n.' .')    / /\\ \\   |  \\| |  / /\\ \\  | .-.\\    \\ \\_/ )/\n|  |(_)  / /__\\ \\  |   | | / /__\\ \\ | `-'/     \\   (_)\n\\  \\     |  __  |  | |\\  | |  __  | |   (       ) (   \n \\  `-.  | |  |)|  | | |)| | |  |)| | |\\ \\      | |   \n  \\____\\ |_|  (_)  /(  (_) |_|  (_) |_| \\)\\    /(_|   \n                  (__)                  (__)  (__)    \n",
    },
    {
        "font": "unarmed",
        "banner": " #####     ###    ##   ##    ###    ######   ##   ##  \n##   ##   ## ##   ###  ##   ## ##   ##   ##  ##   ##  \n##       ##   ##  #### ##  ##   ##  ##   ##  ##   ##  \n##       ##   ##  ## ####  ##   ##  ##   ##   #####   \n##       #######  ##  ###  #######  ######     ###    \n##   ##  ##   ##  ##   ##  ##   ##  ##  ##     ###    \n #####   ##   ##  ##   ##  ##   ##  ##   ##    ###    \n                                                      \n",
    },
    {
        "font": "aquaplan",
        "banner": "  ####      ##     ##  ##     ##     #####    ##  ##  \n ##  ##    ####    ### ##    ####    ##  ##   ##  ##  \n ##       ##  ##   ######   ##  ##   ##  ##   ##  ##  \n ##       ######   ######   ######   #####     ####   \n ##       ##  ##   ## ###   ##  ##   ####       ##    \n ##  ##   ##  ##   ##  ##   ##  ##   ## ##      ##    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "green_be",
        "banner": "  # ###      ##    ##  ##      ##   ### ##   ###  ##  \n ##   #      ##    ###  #      ##    ##  ##   ##   #  \n###        # ##     ### #    # ##    ##  ##    ## #   \n###        #  ##   # ####    #  ##   ## ##      ##    \n###       # ####   #  ###   # ####   ## #       ##    \n ##   #   #   ##   #   ##   #   ##   ##  #      ##    \n  # ###  ### ###  ###  ##  ### ###  #### ##    ####   \n                                                      \n",
    },
    {
        "font": "charact2",
        "banner": "                                                      \n  ####     ####    ##  ##    ####    #####    ##  ##  \n ##  ##   ##  ##   ### ##   ##  ##   ##  ##   ##  ##  \n ##       ##  ##   ######   ##  ##   ##  ##   ##  ##  \n ##       ######   ## ###   ######   #####     ####   \n ##  ##   ##  ##   ##  ##   ##  ##   ## ##      ##    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "rozzo",
        "banner": '                                                  \n e88\'888  ,"Y88b 888 8e   ,"Y88b 888,8, Y8b Y888P \nd888  \'8 "8" 888 888 88b "8" 888 888 "   Y8b Y8P  \nY888   , ,ee 888 888 888 ,ee 888 888      Y8b Y   \n "88,e8\' "88 888 888 888 "88 888 888       888    \n                                           888    \n                                           888    \n',
    },
    {
        "font": "charact1",
        "banner": "                                                      \n ######   ######   ##  ##   ######   ######   ##  ##  \n ### ##   ######   ### ##   ######   ##  ##   ##  ##  \n ###      ##  ##   ######   ##  ##   ##  ##   ##  ##  \n ###      ######   ## ###   ######   ######   ######  \n ### ##   ##  ##   ##  ##   ##  ##   #####      ##    \n ######   ##  ##   ##  ##   ##  ##   ##  ##    ####   \n                                                      \n",
    },
    {
        "font": "future_4",
        "banner": "  ##      ##       ## ##    ##       ###      ##  ##  \n ## #     ###      ## ##    ###      ## ##    ##  ##  \n ##       ####     ### ##   ####     ##  ##    ## ##  \n ##       ## ##    ### ##   ## ##    #####     ####   \n ##       ######   ## # ##  ######   ####       ###   \n ###   #  ##   ##  ##  ###  ##   ##  ## ##       ##   \n   ####   ##    #  ##   ##  ##    #  ##   ##     ##   \n                                                      \n",
    },
    {
        "font": "home_pak",
        "banner": "                                                      \n  #####     ###    #### ##    ###    ######   ### ### \n # # ###   #####   #### ##   #####   ### ###  ### ### \n ###      ### ###  #######  ### ###  ### ###   #####  \n ###      ### ###  #######  ### ###  ######     ###   \n ### ###  #######  ### ###  #######  ### ###    ###   \n   ####   ### ###  ### ###  ### ###  ### ###    ###   \n                                                      \n",
    },
    {
        "font": "trek",
        "banner": "     dBBBP  dBBBBBb     dBBBBb  dBBBBBb   dBBBBBb dBP dBP\n                 BB        dBP       BB       dBP    dBP \n   dBP       dBP BB   dBP dBP    dBP BB   dBBBBK    dBP  \n  dBP       dBP  BB  dBP dBP    dBP  BB  dBP  BB   dBP   \n dBBBBP    dBBBBBBB dBP dBP    dBBBBBBB dBP  dB'  dBP    \n                                                         \n",
    },
    {
        "font": "fbr2",
        "banner": "  ######     #### ######      #### #######   ###  ## \n ###  ##    ##### ###  ##    #####  ###  ##  ###  ## \n ###       ## ### ###  ##   ## ###  ###  ##  ###  ## \n ###      ##  ### ###  ##  ##  ###  ######    #####  \n ###     ######## ###  ## ########  ### ##     ###   \n ###  ## ##   ### ###  ## ##   ###  ###  ##    ###   \n  #####  ##   ### ###  ## ##   ###  ###  ##    ###   \n          ###         ##   ###           ##          \n",
    },
    {
        "font": "computer",
        "banner": "                                     \neeee eeeee eeeee eeeee eeeee  e    e \n8  8 8   8 8   8 8   8 8   8  8    8 \n8e   8eee8 8e  8 8eee8 8eee8e 8eeee8 \n88   88  8 88  8 88  8 88   8   88   \n88e8 88  8 88  8 88  8 88   8   88   \n                                     \n",
    },
    {
        "font": "c2",
        "banner": "                                           #          \n #####        ##  ##   ##       ##  ######   ##  ##   \n#######      ###  ##   ##      ###  #######  ##  ##   \n               #        #        #        #           \n##          ####  ## # ##     ####  ######    ####    \n##         #####  ##  ###    #####  ## ##      ##     \n#######   ##  ##  ##   ##   ##  ##  ##  ##     ##     \n #####   ##   ##  ##   ##  ##   ##  ##   ##    ##     \n",
    },
    {
        "font": "advenger",
        "banner": "  ####     ###    ##   ##    ###    ######   ###  ### \n ##  ##   ## ##   ###  ##   ## ##    ##  ##   ##  ##  \n##       ##   ##  #### ##  ##   ##   ##  ##    ####   \n##       ##   ##  #######  ##   ##   #####      ##    \n##       #######  ## ####  #######   ## ##      ##    \n ##  ##  ##   ##  ##  ###  ##   ##   ## ##      ##    \n  ####   ##   ##  ##   ##  ##   ##  #### ##    ####   \n                                                      \n",
    },
    {
        "font": "doubleshorts",
        "banner": " ____  ___  __  __  ___  _____ _  _ \n((    ||=|| ||\\\\|| ||=|| ||_// \\\\// \n \\\\__ || || || \\|| || || || \\\\  //  \n",
    },
    {
        "font": "block2",
        "banner": "                                                            \n                                                            \n  _|_|_|    _|_|_|  _|_|_|      _|_|_|  _|  _|_|  _|    _|  \n_|        _|    _|  _|    _|  _|    _|  _|_|      _|    _|  \n_|        _|    _|  _|    _|  _|    _|  _|        _|    _|  \n  _|_|_|    _|_|_|  _|    _|    _|_|_|  _|          _|_|_|  \n                                                        _|  \n                                                    _|_|    \n",
    },
    {
        "font": "peaks",
        "banner": "                                                    \n                                                    \n   /^^^   /^^    /^^ /^^     /^^    /^ /^^^/^^   /^^\n /^^    /^^  /^^  /^^  /^^ /^^  /^^  /^^    /^^ /^^ \n/^^    /^^   /^^  /^^  /^^/^^   /^^  /^^      /^^^  \n /^^   /^^   /^^  /^^  /^^/^^   /^^  /^^       /^^  \n   /^^^  /^^ /^^^/^^^  /^^  /^^ /^^^/^^^      /^^   \n                                            /^^     \n",
    },
    {
        "font": "glenyn",
        "banner": "____ ___  __   ___  ____ _    \n| __\\|  \\ | \\|\\|  \\ | . \\||_/\\\n| \\__| . \\|  \\|| . \\|  <_| __/\n|___/|/\\_/|/\\_/|/\\_/|/\\_/|/   \n",
    },
    {
        "font": "tubular",
        "banner": "                                                    \n                                                    \n   O~~~   O~~    O~~ O~~     O~~    O~ O~~~O~~   O~~\n O~~    O~~  O~~  O~~  O~~ O~~  O~~  O~~    O~~ O~~ \nO~~    O~~   O~~  O~~  O~~O~~   O~~  O~~      O~~~  \n O~~   O~~   O~~  O~~  O~~O~~   O~~  O~~       O~~  \n   O~~~  O~~ O~~~O~~~  O~~  O~~ O~~~O~~~      O~~   \n                                            O~~     \n",
    },
    {
        "font": "6x10",
        "banner": "                                          \n                                          \n                                          \n  ###    ###   # ##    ###   # ##   #   # \n #   #      #  ##  #      #  ##  #  #   # \n #       ####  #   #   ####  #      #  ## \n #   #  #   #  #   #  #   #  #       ## # \n  ###    ####  #   #   ####  #          # \n                                    #   # \n                                     ###  \n",
    },
    {
        "font": "z-pilot",
        "banner": "  # ##      #     ##   ##     #     ## ###   ##   ##  \n ## ###    ##     ###  ##    ##     ## ####  ##   ##  \n###  #      ##     ### ##     ##    ##   ##   ## ##   \n##          ##    # #####     ##    ## ####   #  ##   \n##        ## ##   ## ####   ## ##   ## ###      ##    \n###  #    ## ##   ##  ###   ## ##   ##    #     ##    \n ## ###  ## ####  ##   ##  ## ####  ##   ##     ##    \n  # ##   ##   ##  ##    #  ##   ##  ##   ##     ##    \n",
    },
    {
        "font": "fireing",
        "banner": "  ####    ####    #####     ####    #####    #    #   \n #       #    #   #    #   #    #        #   #    #   \n#        #    #   #    #   #    #        #   #    #   \n#        # ####   #    #   # ####   #####     ####    \n#        #    #   #    #   #    #   #    #            \n #       #    #   #    #   #    #   #    #    ####    \n  ####   #    #   #    #   #    #   #    #    ####    \n                                                      \n",
    },
    {
        "font": "clr4x6",
        "banner": "                              \n ##   #   ##    #   ##   # #  \n#    # #  # #  # #  # #  # #  \n#    # #  # #  # #  #     ##  \n ##   ##  # #   ##  #      #  \n                         ##   \n",
    },
    {
        "font": "chartri",
        "banner": "                              \n                              \n                              \n                              \n ##   ## ####    ## # #  #  # \n#    # #  # #   # # ##    ##  \n# # # #  #  #  # #  #     ##  \n #   # # #  ##  # # #     #   \n                          #   \n                        ##    \n",
    },
    {
        "font": "basic",
        "banner": " .o88b.  .d8b.  d8b   db  .d8b.  d8888b. db    db \nd8P  Y8 d8' `8b 888o  88 d8' `8b 88  `8D `8b  d8' \n8P      88ooo88 88V8o 88 88ooo88 88oobY'  `8bd8'  \n8b      88~~~88 88 V8o88 88~~~88 88`8b      88    \nY8b  d8 88   88 88  V888 88   88 88 `88.    88    \n `Y88P' YP   YP VP   V8P YP   YP 88   YD    YP    \n                                                  \n                                                  \n",
    },
    {
        "font": "char1",
        "banner": "                                                      \n  ####      ##     ##  ##     ##     #####    ##  ##  \n ##  ##    ####    ### ##    ####    ##  ##   ##  ##  \n ##       ##  ##   ######   ##  ##   ##  ##    ####   \n ##       ##  ##   ######   ##  ##   #####      ##    \n ##  ##   ######   ## ###   ######   ## ##      ##    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "yie_ar_k",
        "banner": "  #####     ##     ##   #     ##    ######   ##   ##  \n ## ###   #####   #### ##   #####   ###  ##  ##   ##  \n##        ## ###  #######   ## ###  ##   ##  ###  ##  \n##       ##   ##  ## ####  ##   ##  ##  ##     ####   \n##       #######  ##  ###  #######  #####       ##    \n#####    ##  ##   ##   ##  ##  ##    ## ##      ##    \n #####   #   #     #   #   #   #     ##  ##    ##     \n                                                      \n",
    },
    {
        "font": "bulbhead",
        "banner": "  ___    __    _  _    __    ____  _  _ \n / __)  /__\\  ( \\( )  /__\\  (  _ \\( \\/ )\n( (__  /(__)\\  )  (  /(__)\\  )   / \\  / \n \\___)(__)(__)(_)\\_)(__)(__)(_)\\_) (__) \n",
    },
    {
        "font": "zig_zag",
        "banner": "  ####    ######  ######    ######  ######   ##   ##  \n ######  #######  #######  #######  #######  ###  ##  \n### ###  ###  ##  ## ####  ###  ##  ### ###   #####   \n##   #   ##   ##  ##  ###  ##   ##  ##  ##     ###    \n##       ## ####  ##  ###  ## ####  ## ##       ##    \n ##  ##  ##   ##  ##  ##   ##   ##  ##  ##      ##    \n  ####    ##  ##  ##  ###   ##  ##  ##   ##     ##    \n                                                      \n",
    },
    {
        "font": "xcouri",
        "banner": "                                         \n                                         \n                                         \n                                         \n  ###   ###   # ##    ###   # ##   ## ## \n #  #      #   #  #      #   #  #   #  # \n#      #####  #   #  #####  #       #  # \n#  #  #   #   #  #  #   #   #       # #  \n ##    ### # ### ##  ### # ###      ##   \n                                    #    \n                                  ##     \n",
    },
    {
        "font": "funfaces",
        "banner": "   c  c          \\\\\\  ///         ()_()  wWw  wWw \n   (OO)     /)   ((O)(O))    /)   (O o)  (O)  (O) \n ,'.--.)  (o)(O)  | \\ ||   (o)(O)  |^_\\  ( \\  / ) \n/ //_|_\\   //\\\\   ||\\\\||    //\\\\   |(_))  \\ \\/ /  \n| \\___    |(__)|  || \\ |   |(__)|  |  /    \\o /   \n'.    )   /,-. |  ||  ||   /,-. |  )|\\\\   _/ /    \n  `-.'   -'   '' (_/  \\_) -'   '' (/  \\) (_.'     \n",
    },
    {
        "font": "drpepper",
        "banner": "                              \n ___  ___ ._ _  ___  _ _  _ _ \n/ | '<_> || ' |<_> || '_>| | |\n\\_|_.<___||_|_|<___||_|  `_. |\n                         <___'\n",
    },
    {
        "font": "lineblocks",
        "banner": " ______  ______   ______   ______   ______  __    _  \n| |     | |  | | | |  \\ \\ | |  | | | |  | \\ \\ \\  | | \n| |     | |__| | | |  | | | |__| | | |__| |  \\_\\_| | \n|_|____ |_|  |_| |_|  |_| |_|  |_| |_|  \\_\\  ____|_| \n                                                     \n",
    },
    {
        "font": "nancyj-fancy",
        "banner": "                                                      \n                                                      \n.d8888b. .d8888b. 88d888b. .d8888b. 88d888b. dP    dP \n88'  `\"\" 88'  `88 88'  `88 88'  `88 88'  `88 88    88 \n88.  ... 88.  .88 88    88 88.  .88 88       88.  .88 \n`88888P' `88888P8 dP    dP `88888P8 dP       `8888P88 \n                                                  .88 \n                                              d8888P  \n",
    },
    {
        "font": "utopia",
        "banner": "                                 \n                                 \n                                 \n                                 \n ### ###  ####   ###  ## # ## ## \n#  # #  #  #  #  #  #  ##   # #  \n#     ###  #  #   ###  #    # #  \n#    #  #  #  #  #  #  #     #   \n ### #### ### ## #### ###    #   \n                           # #   \n                           ##    \n",
    },
    {
        "font": "sub-zero",
        "banner": ' ______     ______     __   __     ______     ______     __  __    \n/\\  ___\\   /\\  __ \\   /\\ "-.\\ \\   /\\  __ \\   /\\  == \\   /\\ \\_\\ \\   \n\\ \\ \\____  \\ \\  __ \\  \\ \\ \\-.  \\  \\ \\  __ \\  \\ \\  __<   \\ \\____ \\  \n \\ \\_____\\  \\ \\_\\ \\_\\  \\ \\_\\\\"\\_\\  \\ \\_\\ \\_\\  \\ \\_\\ \\_\\  \\/\\_____\\ \n  \\/_____/   \\/_/\\/_/   \\/_/ \\/_/   \\/_/\\/_/   \\/_/ /_/   \\/_____/ \n                                                                   \n',
    },
    {
        "font": "nvscript",
        "banner": '                                                                      \n                                                                      \n                                                                      \n                                                                      \n                                                                      \n   ,gggg,    ,gggg,gg   ,ggg,,ggg,     ,gggg,gg   ,gggggg,  gg     gg \n  dP"  "Yb  dP"  "Y8I  ,8" "8P" "8,   dP"  "Y8I   dP""""8I  I8     8I \n i8\'       i8\'    ,8I  I8   8I   8I  i8\'    ,8I  ,8\'    8I  I8,   ,8I \n,d8,_    _,d8,   ,d8b,,dP   8I   Yb,,d8,   ,d8b,,dP     Y8,,d8b, ,d8I \nP""Y8888PPP"Y8888P"`Y88P\'   8I   `Y8P"Y8888P"`Y88P      `Y8P""Y88P"888\n                                                                 ,d8I\'\n                                                               ,dP\'8I \n                                                              ,8"  8I \n                                                              I8   8I \n                                                              `8, ,8I \n                                                               `Y8P"  \n',
    },
    {
        "font": "sblood",
        "banner": "  @@@@@@@  @@@@@@  @@@  @@@  @@@@@@  @@@@@@@  @@@ @@@\n !@@      @@!  @@@ @@!@!@@@ @@!  @@@ @@!  @@@ @@! !@@\n !@!      @!@!@!@! @!@@!!@! @!@!@!@! @!@!!@!   !@!@! \n :!!      !!:  !!! !!:  !!! !!:  !!! !!: :!!    !!:  \n  :: :: :  :   : : ::    :   :   : :  :   : :   .:   \n                                                     \n",
    },
    {
        "font": "char4",
        "banner": "   ###      ####    ## ##     ####   #####     #  ##  \n ######    #####   ### ##    #####   ######   ##  ##  \n ##       ##  ##   ######   ##  ##   ##  ##   #   ##  \n##        ##  ##  ## ####   ##  ##   #####    ## ##   \n##   ##  ##  ###  ##  ###  ##  ###   ####      ###    \n##  ###  ## ####  ##   ##  ## ####   ## ##     ##     \n ####    ##   ##  ##   ##  ##   ##   ##  ##    ###    \n                                                      \n",
    },
    {
        "font": "future_5",
        "banner": "   ####     ####    ##  ##    ####    #####    ##  ## \n  ### ##   ## ##    ##  ##   ## ##    ##  ##   ##  ## \n ###       ## ##    ### ##   ## ##    ##  ##   ## ##  \n ##        ######  #### ##   ######  ######     ###   \n ##       ##   ##  ## ###   ##   ##  ####      ###    \n ##  ##   ##   ##  ##  ##   ##   ##  ## ##    ##      \n  ####    ##   ##  ##  ##   ##   ##  ##  ###  ##      \n                                                      \n",
    },
    {
        "font": "yie-ar",
        "banner": "  #####     ##     ##   #     ##    ######   ##   ##  \n ## ###   #####   #### ##   #####   ###  ##  ##   ##  \n##        ## ###  #######   ## ###  ##   ##  ###  ##  \n##       ##   ##  ## ####  ##   ##  ##  ##     ####   \n##       #######  ##  ###  #######  #####       ##    \n#####    ##  ##   ##   ##  ##  ##    ## ##      ##    \n #####   #   #     #   #   #   #     ##  ##    ##     \n                                                      \n",
    },
    {
        "font": "greek",
        "banner": "                                             \n                                             \n                                             \n__   __  __  __ _  __  __  __  ___   _  _  _ \n\\ \\ / / /  \\/ /| |/ / /  \\/ / / _ \\ | || || |\n \\ v / ( ()  < | / / ( ()  < | |_) )| \\| |/ |\n  > <   \\__/\\_\\|__/   \\__/\\_\\|  __/  \\_   _/ \n / ^ \\                       | |       | |   \n/_/ \\_\\                      |_|       |_|   \n",
    },
    {
        "font": "moscow",
        "banner": "                                    \n#   #   #   #   #   #   ####   #### \n#   #  # #  #   #  # #  #   # #   # \n #### ##### ##### ##### ####   #### \n    # #   # #   # #   # #      #  # \n    # #   # #   # #   # #     #   # \n",
    },
    {
        "font": "future_8",
        "banner": "                                                      \n                                                      \n #######  #######  ###  ##  #######  #######  ##   ## \n               ##  #### ##       ##       ##  ##   ## \n ##       #######  ## ####  #######  #######  ####### \n ##       ##   ##  ##  ###  ##   ##  ##  ##        ## \n #######  ##   ##  ##   ##  ##   ##  ##   ##  ####### \n                                                      \n",
    },
    {
        "font": "bell",
        "banner": "                                          \n   ___    ___  , __     ___  .___  ,    . \n .'   `  /   ` |'  `.  /   ` /   \\ |    ` \n |      |    | |    | |    | |   ' |    | \n  `._.' `.__/| /    | `.__/| /      `---|.\n                                    \\___/ \n",
    },
    {
        "font": "house_of",
        "banner": "                                                      \n  ####     ####    ##   ##   ####    #####    ##   ## \n ### ##   ######   # #  ##  ######    ## ##   ##   ## \n ##       ##  ##   #### ##  ##  ##    ## ##    #####  \n ##       ######   ## ####  ######    ####       ##   \n ### ##   ##  ##   ##  ###  ##  ##    ## ##   ## ##   \n  ####    ##  ##   ##   ##  ##  ##    ##  ##   ###    \n                                                      \n",
    },
    {
        "font": "red_phoenix",
        "banner": "                                                      \n  ____   _____      ____   _____    _______   ___.__. \n_/ ___\\  \\__  \\    /    \\  \\__  \\   \\_  __ \\ <   |  | \n\\  \\___   / __ \\_ |   |  \\  / __ \\_  |  | \\/  \\___  | \n \\___  > (____  / |___|  / (____  /  |__|     / ____| \n     \\/       \\/       \\/       \\/            \\/      \n                                                      \n",
    },
    {
        "font": "war_of_w",
        "banner": "                                                      \n  ####    #####   ###  ##   #####   ######   ###  ### \n ##  ##   ##  #    ### ##   ##  #    ##  ##   ##  ##  \n ##       ##  ##   ######   ##  ##   #   ##    ####   \n ##       ######   ######   ######   #####      ##    \n###  ##   ##  ##   ## ###   ##  ##   ## ##   #  ##    \n  #### # ###  ### ###  ### ###  ### ###  ###  ####    \n                                                      \n",
    },
    {
        "font": "4max",
        "banner": ' dP""b8    db    88b 88    db    88""Yb Yb  dP \ndP   `"   dPYb   88Yb88   dPYb   88__dP  YbdP  \nYb       dP__Yb  88 Y88  dP__Yb  88"Yb    8P   \n YboodP dP""""Yb 88  Y8 dP""""Yb 88  Yb  dP    \n',
    },
    {
        "font": "georgi16",
        "banner": "                                                           \n                                                           \n                                                           \n                                                           \n                                                           \n  ____      ___    ___  __      ___    ___  __ ____    ___ \n 6MMMMb.  6MMMMb   `MM 6MMb   6MMMMb   `MM 6MM `MM(    )M' \n6M'   Mb 8M'  `Mb   MMM9 `Mb 8M'  `Mb   MM69 \"  `Mb    d'  \nMM    `'     ,oMM   MM'   MM     ,oMM   MM'      YM.  ,P   \nMM       ,6MM9'MM   MM    MM ,6MM9'MM   MM        MM  M    \nMM       MM'   MM   MM    MM MM'   MM   MM        `Mbd'    \nYM.   d9 MM.  ,MM   MM    MM MM.  ,MM   MM         YMP     \n YMMMM9  `YMMM9'Yb._MM_  _MM_`YMMM9'Yb._MM_         M      \n                                                   d'      \n                                               (8),P       \n                                                YMM        \n",
    },
    {
        "font": "lean",
        "banner": "                                                                                \n                                                                                \n    _/_/_/       _/_/_/      _/_/_/        _/_/_/      _/  _/_/      _/    _/   \n _/           _/    _/      _/    _/    _/    _/      _/_/          _/    _/    \n_/           _/    _/      _/    _/    _/    _/      _/            _/    _/     \n _/_/_/       _/_/_/      _/    _/      _/_/_/      _/              _/_/_/      \n                                                                       _/       \n                                                                  _/_/          \n",
    },
    {
        "font": "finalass",
        "banner": " #####    #####   ###  ##   #####   ######   ##   ##  \n##   ##  ##   ##  #### ##  ##   ##  ##   ##  ##   ##  \n##       ##   ##  #######  ##   ##  ##   ##  ##   ##  \n##       #######  ## ####  #######  ######    #####   \n##       ##   ##  ##  ###  ##   ##  ## ##       ##    \n##   ##  ##   ##  ##   ##  ##   ##  ##  ##      ##    \n #####   ##   ##  ##   ##  ##   ##  ##   ##     ##    \n                                                      \n",
    },
    {
        "font": "charact6",
        "banner": "                                                      \n  ####      ##     ##  ##     ##     #####    ##  ##  \n ##  ##    ####    ### ##    ####    ##  ##   ##  ##  \n ##       ##  ##   ######   ##  ##   ##  ##    ####   \n ##       ######   ## ###   ######   #####      ##    \n ##  ##   ##  ##   ##  ##   ##  ##   ## ##      ##    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "zone7",
        "banner": " #####        ##  ##   ##       ##  ######   ##  ##   \n#######      ###  ##   ##      ###  #######  ##  ##   \n               #        #        #        #           \n##          ####  ## # ##     ####  ######    ####    \n##         #####  ##  ###    #####  ## ##      ##     \n#######   ##  ##  ##   ##   ##  ##  ##  ##     ##     \n #####   ##   ##  ##   ##  ##   ##  ##   ##    ##     \n                                                      \n",
    },
    {
        "font": "3x5",
        "banner": "                        \n                        \n###  ## ##   ## ### # # \n#   # # # # # # #   ### \n### ### # # ### #     # \n                    ### \n",
    },
    {
        "font": "o8",
        "banner": "                                                                        \n  ooooooo     ooooooo   oo oooooo     ooooooo   oo oooooo   oooo   oooo \n888     888   ooooo888   888   888    ooooo888   888    888  888   888  \n888         888    888   888   888  888    888   888          888 888   \n  88ooo888   88ooo88 8o o888o o888o  88ooo88 8o o888o           8888    \n                                                             o8o888     \n",
    },
    {
        "font": "banner3",
        "banner": " ######     ###    ##    ##    ###    ########  ##    ## \n##    ##   ## ##   ###   ##   ## ##   ##     ##  ##  ##  \n##        ##   ##  ####  ##  ##   ##  ##     ##   ####   \n##       ##     ## ## ## ## ##     ## ########     ##    \n##       ######### ##  #### ######### ##   ##      ##    \n##    ## ##     ## ##   ### ##     ## ##    ##     ##    \n ######  ##     ## ##    ## ##     ## ##     ##    ##    \n",
    },
    {
        "font": "graffiti",
        "banner": "                                                \n  ____  _____     ____  _____   _______  ___.__.\n_/ ___\\ \\__  \\   /    \\ \\__  \\  \\_  __ \\<   |  |\n\\  \\___  / __ \\_|   |  \\ / __ \\_ |  | \\/ \\___  |\n \\___  >(____  /|___|  /(____  / |__|    / ____|\n     \\/      \\/      \\/      \\/          \\/     \n",
    },
    {
        "font": "catwalk",
        "banner": "                                                    \n                                                    \n   _///   _//    _// _//     _//    _/ _///_//   _//\n _//    _//  _//  _//  _// _//  _//  _//    _// _// \n_//    _//   _//  _//  _//_//   _//  _//      _///  \n _//   _//   _//  _//  _//_//   _//  _//       _//  \n   _///  _// _///_///  _//  _// _///_///      _//   \n                                            _//     \n",
    },
    {
        "font": "swampland",
        "banner": " ______       ________       ___   __       ________       ______        __  __    \n/_____/\\     /_______/\\     /__/\\ /__/\\    /_______/\\     /_____/\\      /_/\\/_/\\   \n\\:::__\\/     \\::: _  \\ \\    \\::\\_\\\\  \\ \\   \\::: _  \\ \\    \\:::_ \\ \\     \\ \\ \\ \\ \\  \n \\:\\ \\  __    \\::(_)  \\ \\    \\:. `-\\  \\ \\   \\::(_)  \\ \\    \\:(_) ) )_    \\:\\_\\ \\ \\ \n  \\:\\ \\/_/\\    \\:: __  \\ \\    \\:. _    \\ \\   \\:: __  \\ \\    \\: __ `\\ \\    \\::::_\\/ \n   \\:\\_\\ \\ \\    \\:.\\ \\  \\ \\    \\. \\`-\\  \\ \\   \\:.\\ \\  \\ \\    \\ \\ `\\ \\ \\     \\::\\ \\ \n    \\_____\\/     \\__\\/\\__\\/     \\__\\/ \\__\\/    \\__\\/\\__\\/     \\_\\/ \\_\\/      \\__\\/ \n                                                                                   \n",
    },
    {
        "font": "hades",
        "banner": "  ####     ##     ##  ###    ##     ######   ##   ##  \n ## ###   ####    ### ###   ####    ##  ###  ##   ##  \n##       ##  ##   #######  ##  ##   ###  ##  ### ##   \n###      #######  ## ####  #######  ######    #####   \n#### ##  ##  ###  ##   ##  ##  ###  ## ##     ####    \n ######  ### ###  ###  ##  ### ###  ### ##     ###    \n  ####   ### ###  ###  ##  ### ###  ###  ##    ###    \n                                                      \n",
    },
    {
        "font": "cli8x8",
        "banner": "                                                      \n                                                      \n   ####     #####  ## ###     #####   ## ###   ##  ## \n ##       ##   ##  ###  ##  ##   ##  ####     ##  ##  \n##       ##    ##  ##   ## ##    ##  ##       ##  ##  \n##       ##  ###  ##   ##  ##  ###  ##         ####   \n #####    ### ##  ##   ##   ### ##  ##           ##   \n                                              ####    \n",
    },
    {
        "font": "xbriteb",
        "banner": "                                       \n                                       \n                                       \n                                       \n #### ####  ######  ####  #### ###  ## \n#   #    #   #   #     #   # #  ##  #  \n#     ####   #   #  ####   #     # ##  \n##    #  #   #   #  #  #   #     # #   \n #### ##### ### ### ##### ###     #    \n                                  #    \n                                ##     \n",
    },
    {
        "font": "whimsy",
        "banner": "                                                        \n                                                        \n                                                        \n d8888b d888b8b    88bd88b  d888b8b    88bd88b?88   d8P \nd8P' `Pd8P' ?88    88P' ?8bd8P' ?88    88P'  `d88   88  \n88b    88b  ,88b  d88   88P88b  ,88b  d88     ?8(  d88  \n`?888P'`?88P'`88bd88'   88b`?88P'`88bd88'     `?88P'?8b \n                                                     )88\n                                                    ,d8P\n                                                 `?888P'\n",
    },
    {
        "font": "rounded",
        "banner": "                                          \n                                          \n  ____  _____  ____   _____   ____  _   _ \n / ___)(____ ||  _ \\ (____ | / ___)| | | |\n( (___ / ___ || | | |/ ___ || |    | |_| |\n \\____)\\_____||_| |_|\\_____||_|     \\__  |\n                                   (____/ \n",
    },
    {
        "font": "assalt_m",
        "banner": " #######   ######  ##  ###   ######  ######   ##  ### \n ##  ###   ##  ##  ### ###   ##  ##  ##  ##   ##  ### \n ##  ###   ##  ##  #######   ##  ##  ##  ##   ##  ### \n ##       #######  ## ####  #######  #######  ####### \n ##   ##  ###  ##  ##  ###  ###  ##  ### ###    ###   \n ##   ##  ###  ##  ##  ###  ###  ##  ### ###    ###   \n #######  ###  ##  ##  ###  ###  ##  ### ###    ###   \n                                                      \n",
    },
    {
        "font": "alligator2",
        "banner": " ::::::::      :::     ::::    :::     :::     :::::::::  :::   ::: \n:+:    :+:   :+: :+:   :+:+:   :+:   :+: :+:   :+:    :+: :+:   :+: \n+:+         +:+   +:+  :+:+:+  +:+  +:+   +:+  +:+    +:+  +:+ +:+  \n+#+        +#++:++#++: +#+ +:+ +#+ +#++:++#++: +#++:++#:    +#++:   \n+#+        +#+     +#+ +#+  +#+#+# +#+     +#+ +#+    +#+    +#+    \n#+#    #+# #+#     #+# #+#   #+#+# #+#     #+# #+#    #+#    #+#    \n ########  ###     ### ###    #### ###     ### ###    ###    ###    \n",
    },
    {
        "font": "varsity",
        "banner": "                                                     \n                                                     \n .---.   ,--.    _ .--.    ,--.    _ .--.    _   __  \n/ /'`\\] `'_\\ :  [ `.-. |  `'_\\ :  [ `/'`\\]  [ \\ [  ] \n| \\__.  // | |,  | | | |  // | |,  | |       \\ '/ /  \n'.___.' \\'-;__/ [___||__] \\'-;__/ [___]    [\\_:  /   \n                                            \\__.'    \n",
    },
    {
        "font": "xhelvi",
        "banner": "                                     \n                                     \n                                     \n                                     \n                                     \n  ##   ###   # ##   ###   # ##  #  # \n #  #     #  ##  #     #  ##    #  # \n#      ####  #   #  ####  #     # #  \n#     #  #  #   #  #  #  #      # #  \n#  #  #  #  #   #  #  #  #       #   \n ##    ## # #   #   ## # #       #   \n                                #    \n                               #     \n",
    },
    {
        "font": "druid",
        "banner": "                                                      \n ## ##   ######   ###  ##  ######   ######   ### ###  \n##  # #     ## #   ###  #     ## #       ##   ##  ##  \n#   #      ##  #   #### #    ##  #   ##   #   ##  ##  \n#  ##      #####   ## # #    #####  #######    ####   \n## #      ##   #   ## ###   ##   #   ####       ##    \n###   #   ##   #   ##  ##   ##   #   ## ##     ##     \n #####   ##   ##  ###   #  ##   ##  ###  ##   ##      \n",
    },
    {
        "font": "tiles",
        "banner": "                                                    \n                                                    \n   [...   [..    [.. [..     [..    [. [...[..   [..\n [..    [..  [..  [..  [.. [..  [..  [..    [.. [.. \n[..    [..   [..  [..  [..[..   [..  [..      [...  \n [..   [..   [..  [..  [..[..   [..  [..       [..  \n   [...  [.. [...[...  [..  [.. [...[...      [..   \n                                            [..     \n",
    },
    {
        "font": "cricket",
        "banner": "                                        \n.----..---.-..-----..---.-..----..--.--.\n|  __||  _  ||     ||  _  ||   _||  |  |\n|____||___._||__|__||___._||__|  |___  |\n                                 |_____|\n                                        \n                                        \n                                        \n",
    },
    {
        "font": "isometric3",
        "banner": "      ___           ___           ___           ___           ___                 \n     /  /\\         /  /\\         /__/\\         /  /\\         /  /\\          ___   \n    /  /:/        /  /::\\        \\  \\:\\       /  /::\\       /  /::\\        /__/|  \n   /  /:/        /  /:/\\:\\        \\  \\:\\     /  /:/\\:\\     /  /:/\\:\\      |  |:|  \n  /  /:/  ___   /  /:/~/::\\   _____\\__\\:\\   /  /:/~/::\\   /  /:/~/:/      |  |:|  \n /__/:/  /  /\\ /__/:/ /:/\\:\\ /__/::::::::\\ /__/:/ /:/\\:\\ /__/:/ /:/___  __|__|:|  \n \\  \\:\\ /  /:/ \\  \\:\\/:/__\\/ \\  \\:\\~~\\~~\\/ \\  \\:\\/:/__\\/ \\  \\:\\/:::::/ /__/::::\\  \n  \\  \\:\\  /:/   \\  \\::/       \\  \\:\\  ~~~   \\  \\::/       \\  \\::/~~~~     ~\\~~\\:\\ \n   \\  \\:\\/:/     \\  \\:\\        \\  \\:\\        \\  \\:\\        \\  \\:\\           \\  \\:\\\n    \\  \\::/       \\  \\:\\        \\  \\:\\        \\  \\:\\        \\  \\:\\           \\__\\/\n     \\__\\/         \\__\\/         \\__\\/         \\__\\/         \\__\\/                \n",
    },
    {
        "font": "pebbles",
        "banner": "                                        \n                                        \n                                        \n                                        \n.oOo  .oOoO' 'OoOo. .oOoO' `OoOo. O   o \nO     O   o   o   O O   o   o     o   O \no     o   O   O   o o   O   O     O   o \n`OoO' `OoO'o  o   O `OoO'o  o     `OoOO \n                                      o \n                                   OoO' \n",
    },
    {
        "font": "big",
        "banner": "                                        \n                                        \n  ___   __ _  _ __    __ _  _ __  _   _ \n / __| / _` || '_ \\  / _` || '__|| | | |\n| (__ | (_| || | | || (_| || |   | |_| |\n \\___| \\__,_||_| |_| \\__,_||_|    \\__, |\n                                   __/ |\n                                  |___/ \n",
    },
    {
        "font": "pawp",
        "banner": "                                         \n                                         \n               _             _           \n   ___   ____ (_)__    ____ (_)__  _   _ \n _(___) (____)(____)  (____)(____)(_) (_)\n(_)___ ( )_( )(_) (_)( )_( )(_)   (_)_(_)\n (____) (__)_)(_) (_) (__)_)(_)    (____)\n                                    __(_)\n                                   (___) \n",
    },
    {
        "font": "amcneko",
        "banner": "                                                                           \n.sSSSSs.    .sSSSSs.    .sSSSs.  SSSSS .sSSSSs.    .sSSSSSSSs. .sSSS SSSSS \nS SSSSSSSs. S SSSSSSSs. S SSS SS SSSSS S SSSSSSSs. S SSS SSSSS S SSS SSSSS \nS  SS SSSS' S  SS SSSSS S  SS  `sSSSSS S  SS SSSSS S  SS SSSS' S  SS SSSSS \nS..SS       S..SSsSSSSS S..SS    SSSSS S..SSsSSSSS S..SSsSSSa. `..SSsSSSS' \nS:::S SSSSS S:::S SSSSS S:::S    SSSSS S:::S SSSSS S:::S SSSSS    S:::S    \nS;;;S SSSSS S;;;S SSSSS S;;;S    SSSSS S;;;S SSSSS S;;;S SSSSS    S;;;S    \nS%%%S SSSSS S%%%S SSSSS S%%%S    SSSSS S%%%S SSSSS S%%%S SSSSS    S%%%S    \nSSSSSsSSSSS SSSSS SSSSS SSSSS    SSSSS SSSSS SSSSS SSSSS SSSSS    SSSSS    \n                                                                           \n",
    },
    {
        "font": "spliff",
        "banner": " _____  _____  _____  _____  _____ ___ ___\n/     \\/  _  \\/  _  \\/  _  \\/  _  \\\\  |  /\n|  |--||  _  ||  |  ||  _  ||  _  < |   | \n\\_____/\\__|__/\\__|__/\\__|__/\\__|\\_/ \\___/ \n                                          \n",
    },
    {
        "font": "xsans",
        "banner": "                               \n                               \n                               \n ###  ##   # #   ##   # # #  # \n#       #  ## #    #  ### #  # \n#     ###  #  #  ###  #   #  # \n#    #  #  #  # #  #  #   #  # \n#    #  #  #  # #  #  #    ##  \n ###  ## # #  #  ## # #    ##  \n                           #   \n                          ##   \n",
    },
    {
        "font": "clr8x8",
        "banner": "                                                      \n                                                      \n  #####    ######  # ####    ######   # ###   #    #  \n #        #     #  ##    #  #     #   ##      #    #  \n #        #     #  #     #  #     #   #       #    #  \n #        #    ##  #     #  #    ##   #        #####  \n  #####    #### #  #     #   #### #   #            #  \n                                               ####   \n",
    },
    {
        "font": "char2",
        "banner": " #####       ##   ##  ##       ##   ######    ##  ##  \n#######    #####  ### ##     #####  #######   ##  ##  \n##   ##    ## ##  ######     ## ##       ##   ##  ##  \n##        ##  ##  ######    ##  ##  ######     ####   \n##   ##   ######  ## ###    ######  ##   ##     ##    \n#######  ##   ##  ##  ##   ##   ##  ##   ##     ##    \n #####   ##   ##  ##  ##   ##   ##  ##   ##     ##    \n                                                      \n",
    },
    {
        "font": "kik_star",
        "banner": "  ####     ###    ##   ##    ###    ######    ##  ##  \n ##  ##   ## ##   ###  ##   ## ##   ###  ##   ##  ##  \n##       ##   ##  #### ##  ##   ##  ##   ##   ##  ##  \n##       ##   ##  #######  ##   ##  ##  ##     ####   \n##       #######  ## ####  #######  #####       ##    \n ##  ##  ##   ##  ##  ###  ##   ##  ## ###      ##    \n  ####   ##   ##  ##   ##  ##   ##  ##  ###     ##    \n                                                      \n",
    },
    {
        "font": "nancyj",
        "banner": "                                                      \n                                                      \n.d8888b. .d8888b. 88d888b. .d8888b. 88d888b. dP    dP \n88'  `\"\" 88'  `88 88'  `88 88'  `88 88'  `88 88    88 \n88.  ... 88.  .88 88    88 88.  .88 88       88.  .88 \n`88888P' `88888P8 dP    dP `88888P8 dP       `8888P88 \n                                                  .88 \n                                              d8888P  \n",
    },
    {
        "font": "clb6x10",
        "banner": "                                          \n                                          \n                                          \n  ####   ####  # ##    ####  # ###  ## ## \n ##     ## ##  ## ##  ## ##  ###    ## ## \n ##     ## ##  ## ##  ## ##  ##     ## ## \n ##     ## ##  ## ##  ## ##  ##     ## ## \n  ####   ## #  ## ##   ## #  ##      #### \n                                       ## \n                                     ###  \n",
    },
    {
        "font": "3d_diagonal",
        "banner": "                                                                          \n                                                                          \n                                                                          \n                                                                          \n                               ,---,                  __  ,-.             \n                           ,-+-. /  |               ,' ,'/ /|             \n   ,---.      ,--.--.     ,--.'|'   |    ,--.--.    '  | |' |       .--,  \n  /     \\    /       \\   |   |  ,\"' |   /       \\   |  |   ,'     /_ ./|  \n /    / '   .--.  .-. |  |   | /  | |  .--.  .-. |  '  :  /    , ' , ' :  \n.    ' /     \\__\\/: . .  |   | |  | |   \\__\\/: . .  |  | '    /___/ \\: |  \n'   ; :__    ,\" .--.; |  |   | |  |/    ,\" .--.; |  ;  : |     .  \\  ' |  \n'   | '.'|  /  /  ,.  |  |   | |--'    /  /  ,.  |  |  , ;      \\  ;   :  \n|   :    : ;  :   .'   \\ |   |/       ;  :   .'   \\  ---'        \\  \\  ;  \n \\   \\  /  |  ,     .-./ '---'        |  ,     .-./               :  \\  \\ \n  `----'    `--`---'                   `--`---'                    \\  ' ; \n                                                                    `--`  \n",
    },
    {
        "font": "clr5x10",
        "banner": "                                    \n                                    \n                                    \n  ###   ###  ###    ###  # ##  #  # \n #     #  #  #  #  #  #  ##    #  # \n #     #  #  #  #  #  #  #     #  # \n #     # ##  #  #  # ##  #     #  # \n  ###   # #  #  #   # #  #      ### \n                                  # \n                                ##  \n",
    },
    {
        "font": "asslt_m",
        "banner": " #######   ######  ##  ###   ######  ######   ##  ### \n ##  ###   ##  ##  ### ###   ##  ##  ##  ##   ##  ### \n ##  ###   ##  ##  #######   ##  ##  ##  ##   ##  ### \n ##       #######  ## ####  #######  #######  ####### \n ##   ##  ###  ##  ##  ###  ###  ##  ### ###    ###   \n ##   ##  ###  ##  ##  ###  ###  ##  ### ###    ###   \n #######  ###  ##  ##  ###  ###  ##  ### ###    ###   \n                                                      \n",
    },
    {
        "font": "caligraphy",
        "banner": "                                                                          \n                                                                          \n                                                                          \n                                                                          \n                                                                          \n                                              ***  ****    **   ****      \n   ****       ****    ***  ****       ****     **** **** *  **    ***  *  \n  * ***  *   * ***  *  **** **** *   * ***  *   **   ****   **     ****   \n *   ****   *   ****    **   ****   *   ****    **          **      **    \n**         **    **     **    **   **    **     **          **      **    \n**         **    **     **    **   **    **     **          **      **    \n**         **    **     **    **   **    **     **          **      **    \n**         **    **     **    **   **    **     **          **      **    \n***     *  **    **     **    **   **    **     ***          *********    \n *******    ***** **    ***   ***   ***** **     ***           **** ***   \n  *****      ***   **    ***   ***   ***   **                        ***  \n                                                              *****   *** \n                                                            ********  **  \n                                                           *      ****    \n                                                                          \n                                                                          \n",
    },
    {
        "font": "amcslash",
        "banner": "                                                          \n.s5SSSs.  .s5SSSs.  .s    s.  .s5SSSs.  .s5SSSs.  .s5 s.  \n      SS.       SS.       SS.       SS.       SS.     SS. \nsS    `:; sS    S%S sSs.  S%S sS    S%S sS    S%S ssS SSS \nSS        SSSs. S%S SS `S.S%S SSSs. S%S SS .sS;:'  SSSSS  \nSS        SS    S%S SS  `sS%S SS    S%S SS    ;,    SSS   \nSS        SS    `:; SS    `:; SS    `:; SS    `:;   `:;   \nSS    ;,. SS    ;,. SS    ;,. SS    ;,. SS    ;,.   ;,.   \n`:;;;;;:' :;    ;:' :;    ;:' :;    ;:' `:    ;:'   ;:'   \n                                                          \n",
    },
    {
        "font": "faces_of",
        "banner": "                                                      \n #####    #######  ###  ##  #######  #######  ##  ##  \n ##  ###  ##   ##  #### ##  ##   ##  ##   ##  ##  ##  \n ##       #### ##  #### ##  #### ##  ##   ##   ##  ## \n ##       #######  ## ####  #######  #######   ## ### \n ##       ## ####  ##  ###  ## ####  ##  ##     ###   \n ##  ###  ##   ##  ##   ##  ##   ##  ##   ##     ##   \n #####    ##   ##  ##  ##   ##   ##   ##  ##     ##   \n",
    },
    {
        "font": "horizontalright",
        "banner": " _______   ______    _______   ______    _______         _  \n/ _____ \\ |_. _  '. |__   _.' |_. _  '. |_  ___ \\  ____.'_| \n| \\   / |  _||_/  /  _.' .'_   _||_/  /  /  \\_/ | |___. '.  \n\\_/   \\_/ |_____.'  |_______| |_____.'  |_/'.__.'      '._| \n                                                            \n                                                            \n",
    },
    {
        "font": "univers",
        "banner": '                                                                          \n                                                                          \n                                                                          \n                                                                          \n ,adPPYba,  ,adPPYYba,  8b,dPPYba,   ,adPPYYba,  8b,dPPYba,  8b       d8  \na8"     ""  ""     `Y8  88P\'   `"8a  ""     `Y8  88P\'   "Y8  `8b     d8\'  \n8b          ,adPPPPP88  88       88  ,adPPPPP88  88           `8b   d8\'   \n"8a,   ,aa  88,    ,88  88       88  88,    ,88  88            `8b,d8\'    \n `"Ybbd8"\'  `"8bbdP"Y8  88       88  `"8bbdP"Y8  88              Y88\'     \n                                                                 d8\'      \n                                                                d8\'       \n',
    },
    {
        "font": "puzzle",
        "banner": "     _         _         _         _         _         _    \n   _( )__    _( )__    _( )__    _( )__    _( )__    _( )__ \n _|     _| _|     _| _|     _| _|     _| _|     _| _|     _|\n(_ C _ (_ (_ A _ (_ (_ N _ (_ (_ A _ (_ (_ R _ (_ (_ Y _ (_ \n  |_( )__|  |_( )__|  |_( )__|  |_( )__|  |_( )__|  |_( )__|\n",
    },
    {
        "font": "utopiabi",
        "banner": "                                         \n                                         \n                                         \n                                         \n  ###   #### #####    #### ### #   ## ## \n #  #  #  ##  ## ##  #  ##  ####   ## ## \n##    ## ##   ## ## ## ##   ##     ## #  \n##    ## ##  ## ##  ## ##  ##      ###   \n####  ###### ## ### ###### ##      ##    \n                                 # #     \n                                 ##      \n",
    },
    {
        "font": "calgphy2",
        "banner": "                                                                          \n                                                                          \n                                                                          \n                                                                          \n                                                                          \n                                                                          \n   /###       /###    ###  /###       /###    ###  /###    ##   ####      \n  / ###  /   / ###  /  ###/ #### /   / ###  /  ###/ #### /  ##    ###  /  \n /   ###/   /   ###/    ##   ###/   /   ###/    ##   ###/   ##     ###/   \n##         ##    ##     ##    ##   ##    ##     ##          ##      ##    \n##         ##    ##     ##    ##   ##    ##     ##          ##      ##    \n##         ##    ##     ##    ##   ##    ##     ##          ##      ##    \n##         ##    ##     ##    ##   ##    ##     ##          ##      ##    \n###     /  ##    /#     ##    ##   ##    /#     ##          ##      ##    \n ######/    ####/ ##    ###   ###   ####/ ##    ###          #########    \n  #####      ###   ##    ###   ###   ###   ##    ###           #### ###   \n                                                                     ###  \n                                                              #####   ### \n                                                            /#######  /#  \n                                                           /      ###/    \n",
    },
    {
        "font": "fbr1",
        "banner": "  ####     ###    ### ###    ###     #####   ###  ##  \n ##  ##   #####    ### #    #####     ##  #  ###  ##  \n###       ## ##    # ###    ## ##     #  ##   ## ###  \n####  #  ##   ##   #   #   ##   ##   #####   # #####  \n#######  #######  ### ###  #######   ## ###  ## ###   \n#######  ### ###  ### ###  ### ###  ### ###  ######   \n #####   ### ###  ### ###  ### ###  ### ###  #####    \n                                                      \n",
    },
    {
        "font": "baz_bil",
        "banner": " ####    ####     ##   #   ####     #####    ##   #   \n##   #   ##  #    ###  #   ##  #    ##   #   ##   #   \n##       ##   #   ###  #   ##   #   ##   #    ## #    \n##       ######   ## # #   ######   ##   #     ##     \n##       ##   #   ## # #   ##   #   #####      ##     \n##       ##   #   ##  ##   ##   #   ## #       ##     \n##   #   ##   #   ##  ##   ##   #   ##  #      ##     \n ####    ##   #   ##   #   ##   #   ##   #     ##     \n",
    },
    {
        "font": "heavy_me",
        "banner": "  ####      ##    ##   ##     ##    ######   ##    ## \n ##  ##    ####   ###  ##    ####    ##  ##  ##    ## \n##         ####   #### ##    ####    ##  ##   ##  ##  \n##        ##  ##  ## ####   ##  ##   #####     ####   \n##        ######  ##  ###   ######   ## ##      ##    \n ##  ##  ##    ## ##   ##  ##    ##  ##  ##     ##    \n  ####   ##    ## ##   ##  ##    ##  ##   ##   ####   \n                                                      \n",
    },
    {
        "font": "alligator3",
        "banner": " ::::::::      :::     ::::    :::     :::     :::::::::  :::   ::: \n:+:    :+:   :+: :+:   :+:+:   :+:   :+: :+:   :+:    :+: :+:   :+: \n+:+         +:+   +:+  :+:+:+  +:+  +:+   +:+  +:+    +:+  +:+ +:+  \n+#+        +#++:++#++: +#+ +:+ +#+ +#++:++#++: +#++:++#:    +#++:   \n+#+        +#+     +#+ +#+  +#+#+# +#+     +#+ +#+    +#+    +#+    \n#+#    #+# #+#     #+# #+#   #+#+# #+#     #+# #+#    #+#    #+#    \n ########  ###     ### ###    #### ###     ### ###    ###    ###    \n",
    },
    {
        "font": "hollywood",
        "banner": "                                                                        \n                                                                        \n                                                                        \n     ____        ____      ,____      ____       ____                   \n   /'    )--   /'    )    /'    )   /'    )    )'    )--         /'    /\n /'          /'    /'   /'    /'  /'    /'   /'                /'    /' \n(___,/      (___,/(__ /'    /(__ (___,/(__ /'                 (___,/(__ \n                                                                 /'     \n                                                         /     /'       \n                                                        (___,/'         \n",
    },
    {
        "font": "clr7x8",
        "banner": "                                                \n                                                \n  ####    #####  # ###    #####  # ###   #    # \n #       #    #  ##   #  #    #  ##      #    # \n #       #    #  #    #  #    #  #       #    # \n #       #   ##  #    #  #   ##  #        ##### \n  ####    ### #  #    #   ### #  #            # \n                                          ####  \n",
    },
    {
        "font": "heroboti",
        "banner": "                                                      \n                                              ##   ## \n   ####     #####  #####      #####   #####   ##   ## \n  #####    ######  ######    ######  #######  ####### \n ###      ###  ##  ##  ###  ###  ##  ##   ##   ###### \n ##       ##   ##  ##   ##  ##   ##  ##            ## \n #######  #######  ##   ##  #######  ##       ####### \n  ######   #####   ##   ##   #####   ##       ######  \n",
    },
    {
        "font": "xtty",
        "banner": "                              \n                              \n                              \n ###  ##  # #   ##  # ## #  # \n#       # ## #    # ## # #  # \n#     ### #  #  ### #    #  # \n#    #  # #  # #  # #     ##  \n#    # ## #  # # ## #     ##  \n ###  # # #  #  # # #     #   \n                         #    \n                         #    \n",
    },
    {
        "font": "future_6",
        "banner": "  #####     ##     ##   #     ##    ######   ##   ##  \n ## ###   #####   #### ##   #####   ###  ##  ##   ##  \n##        ## ###  #######   ## ###  ##   ##  ###  ##  \n##       ##   ##  ## ####  ##   ##  ##  ##     ####   \n##       #######  ##  ###  #######  #####       ##    \n#####    ##  ##   ##   ##  ##  ##    ## ##      ##    \n #####   #   #     #   #   #   #     ##  ##    ##     \n                                                      \n",
    },
    {
        "font": "clr6x6",
        "banner": "                                          \n  ###    ####  # ##    ####  # ##   #   # \n #      #   #  ##  #  #   #  ##     #   # \n #      #  ##  #   #  #  ##  #       #### \n  ###    ## #  #   #   ## #  #          # \n                                     ###  \n",
    },
    {
        "font": "fire_font-s",
        "banner": "                                         \n                                         \n          )              )   (     (     \n  (    ( /(    (      ( /(   )(    )\\ )  \n  )\\   )(_))   )\\ )   )(_)) (()\\  (()/(  \n ((_) ((_)_   _(_/(  ((_)_   ((_)  )(_)) \n/ _|  / _` | | ' \\)) / _` | | '_| | || | \n\\__|  \\__,_| |_||_|  \\__,_| |_|    \\_, | \n                                   |__/  \n",
    },
    {
        "font": "georgia11",
        "banner": "                                                           \n                                                           \n                                                           \n                                                           \n ,p6\"bo   ,6\"Yb.  `7MMpMMMb.   ,6\"Yb.  `7Mb,od8 `7M'   `MF'\n6M'  OO  8)   MM    MM    MM  8)   MM    MM' \"'   VA   ,V  \n8M        ,pm9MM    MM    MM   ,pm9MM    MM        VA ,V   \nYM.    , 8M   MM    MM    MM  8M   MM    MM         VVV    \n YMbmd'  `Moo9^Yo..JMML  JMML.`Moo9^Yo..JMML.       ,V     \n                                                   ,V      \n                                                OOb\"       \n",
    },
    {
        "font": "isometric1",
        "banner": "      ___           ___           ___           ___           ___           ___     \n     /\\  \\         /\\  \\         /\\__\\         /\\  \\         /\\  \\         |\\__\\    \n    /::\\  \\       /::\\  \\       /::|  |       /::\\  \\       /::\\  \\        |:|  |   \n   /:/\\:\\  \\     /:/\\:\\  \\     /:|:|  |      /:/\\:\\  \\     /:/\\:\\  \\       |:|  |   \n  /:/  \\:\\  \\   /::\\~\\:\\  \\   /:/|:|  |__   /::\\~\\:\\  \\   /::\\~\\:\\  \\      |:|__|__ \n /:/__/ \\:\\__\\ /:/\\:\\ \\:\\__\\ /:/ |:| /\\__\\ /:/\\:\\ \\:\\__\\ /:/\\:\\ \\:\\__\\     /::::\\__\\\n \\:\\  \\  \\/__/ \\/__\\:\\/:/  / \\/__|:|/:/  / \\/__\\:\\/:/  / \\/_|::\\/:/  /    /:/~~/~   \n  \\:\\  \\            \\::/  /      |:/:/  /       \\::/  /     |:|::/  /    /:/  /     \n   \\:\\  \\           /:/  /       |::/  /        /:/  /      |:|\\/__/     \\/__/      \n    \\:\\__\\         /:/  /        /:/  /        /:/  /       |:|  |                  \n     \\/__/         \\/__/         \\/__/         \\/__/         \\|__|                  \n",
    },
    {
        "font": "merlin1",
        "banner": '  ______         __       _____  ___         __        _______    ___  ___  \n /" _  "\\       /""\\     (\\"   \\|"  \\       /""\\      /"      \\  |"  \\/"  | \n(: ( \\___)     /    \\    |.\\\\   \\    |     /    \\    |:        |  \\   \\  /  \n \\/ \\         /\' /\\  \\   |: \\.   \\\\  |    /\' /\\  \\   |_____/   )   \\\\  \\/   \n //  \\ _     //  __\'  \\  |.  \\    \\. |   //  __\'  \\   //      /    /   /    \n(:   _) \\   /   /  \\\\  \\ |    \\    \\ |  /   /  \\\\  \\ |:  __   \\   /   /     \n \\_______) (___/    \\___) \\___|\\____\\) (___/    \\___)|__|  \\___) |___/      \n                                                                            \n',
    },
    {
        "font": "rowancap",
        "banner": '   .aMMMb     .aMMMb     dMMMMb     .aMMMb     dMMMMb    dMP dMP \n  dMP"VMP    dMP"dMP    dMP dMP    dMP"dMP    dMP.dMP   dMP.dMP  \n dMP        dMMMMMP    dMP dMP    dMMMMMP    dMMMMK"    VMMMMP   \ndMP.aMP    dMP dMP    dMP dMP    dMP dMP    dMP"AMF   dA .dMP    \nVMMMP"    dMP dMP    dMP dMP    dMP dMP    dMP dMP    VMMMP"     \n                                                                 \n',
    },
    {
        "font": "kgames_i",
        "banner": "                                                      \n  ####      ##     ##  ##     ##     #####    ##  ##  \n ##  ##    ####    ### ##    ####    ##  ##   ##  ##  \n ##       ##  ##   ######   ##  ##   ##  ##    ####   \n ##       ##  ##   ######   ##  ##   #####      ##    \n ##  ##   ######   ## ###   ######   ## ##      ##    \n  ####    ##  ##   ##  ##   ##  ##   ##  ##     ##    \n                                                      \n",
    },
    {
        "font": "cyberlarge",
        "banner": " _______ _______ __   _ _______  ______ __   __\n |       |_____| | \\  | |_____| |_____/   \\_/  \n |_____  |     | |  \\_| |     | |    \\_    |   \n                                               \n",
    },
    {
        "font": "coinstak",
        "banner": "                                                    \n                                                    \n   O)))   O))    O)) O))     O))    O) O)))O))   O))\n O))    O))  O))  O))  O)) O))  O))  O))    O)) O)) \nO))    O))   O))  O))  O))O))   O))  O))      O)))  \n O))   O))   O))  O))  O))O))   O))  O))       O))  \n   O)))  O)) O)))O)))  O))  O)) O)))O)))      O))   \n                                            O))     \n",
    },
    {
        "font": "usaflag",
        "banner": " :::===== :::====  :::= === :::====  :::====  ::: ===\n :::      :::  === :::===== :::  === :::  === ::: ===\n ===      ======== ======== ======== =======   ===== \n ===      ===  === === ==== ===  === === ===    ===  \n  ======= ===  === ===  === ===  === ===  ===   ===  \n                                                     \n",
    },
    {
        "font": "smpoison",
        "banner": "                                                     \n @@@@@@@  @@@@@@  @@@  @@@  @@@@@@  @@@@@@@  @@@ @@@ \n!@@      @@!  @@@ @@!@!@@@ @@!  @@@ @@!  @@@ @@! !@@ \n!@!      @!@!@!@! @!@@!!@! @!@!@!@! @!@!!@!   !@!@!  \n:!!      !!:  !!! !!:  !!! !!:  !!! !!: :!!    !!:   \n :: :: :  :   : : ::    :   :   : :  :   : :   .:    \n                                                     \n",
    },
    {
        "font": "alligator",
        "banner": "      ::::::::           :::        ::::    :::           :::        :::::::::    :::   ::: \n    :+:    :+:        :+: :+:      :+:+:   :+:         :+: :+:      :+:    :+:   :+:   :+:  \n   +:+              +:+   +:+     :+:+:+  +:+        +:+   +:+     +:+    +:+    +:+ +:+    \n  +#+             +#++:++#++:    +#+ +:+ +#+       +#++:++#++:    +#++:++#:      +#++:      \n +#+             +#+     +#+    +#+  +#+#+#       +#+     +#+    +#+    +#+      +#+        \n#+#    #+#      #+#     #+#    #+#   #+#+#       #+#     #+#    #+#    #+#      #+#         \n########       ###     ###    ###    ####       ###     ###    ###    ###      ###          \n",
    },
    {
        "font": "c1",
        "banner": " #####      ##    ##   ##     ##    ######   ##  ##   \n##   ##    ####   ###  ##    ####    ##  ##  ##  ##   \n##        ##  ##  #### ##   ##  ##   ##  ##  ##  ##   \n##        ######  ## ####   ######   #####    ####    \n##        ##  ##  ##  ###   ##  ##   ####      ##     \n##   ##   ##  ##  ##   ##   ##  ##   ## ##     ##     \n #####    ##  ##  ##   ##   ##  ##  ###  ##   ####    \n                                                      \n",
    },
    {
        "font": "clb8x10",
        "banner": "                                                      \n                                                      \n                                                      \n  #####    ######  ## ###    ######  ## ###   ##  ##  \n ##       ##   ##  ###  ##  ##   ##  ###      ##  ##  \n ##       ##   ##  ##   ##  ##   ##  ##       ##  ##  \n ##       ##  ###  ##   ##  ##  ###  ##       ##  ##  \n  #####    ### ##  ##   ##   ### ##  ##        #####  \n                                                  ##  \n                                               ####   \n",
    },
]
